@@ -18,8 +18,8 @@ import java.util.TreeSet;
 
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * 辞書クラス。
@@ -32,7 +32,7 @@ public class Wdic {
     private static final String ENCODING = "UTF-8";
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** 辞書グループ */
     private WdicGroup _group = null;
     /** 辞書ファイル */
@@ -56,7 +56,7 @@ public class Wdic {
      */
     public Wdic(WdicGroup group, String part, File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _group = group;
         if (part.endsWith("編")) {
             int len = part.length();
@@ -212,7 +212,7 @@ public class Wdic {
      *
      */
     private void _load() {
-        _log.info("load file: " + _file.getPath());
+        _logger.info("load file: " + _file.getPath());
 
         LineNumberReader lnr = null;
         try {
@@ -261,10 +261,10 @@ public class Wdic {
                         continue;
                     }
                     if (item == null) {
-                        _log.warn("unknown context: "
-                                  + _file.getName()
-                                  + "[" + lnr.getLineNumber() + "] "
-                                  + "'" + line + "'");
+                        _logger.warn("unknown context: "
+                                     + _file.getName()
+                                     + "[" + lnr.getLineNumber() + "] "
+                                     + "'" + line + "'");
                         continue;
                     }
                     String block = WdicUtil.deleteTab(line);
@@ -281,10 +281,10 @@ public class Wdic {
                         String str = block.substring(idx).trim();
                         idx = str.indexOf(":");
                         if (idx == -1) {
-                            _log.warn("undefined language: "
-                                      + _file.getName()
-                                      + "[" + lnr.getLineNumber() + "] "
-                                      + "'" + line + "'");
+                            _logger.warn("undefined language: "
+                                         + _file.getName()
+                                         + "[" + lnr.getLineNumber() + "] "
+                                         + "'" + line + "'");
                             item.addSpell("en", str);
                         } else {
                             String lang = str.substring(0, idx).trim();
@@ -331,10 +331,10 @@ public class Wdic {
                         } else if (block.startsWith("//LINK")) {
                         } else {
                             ignore = true;
-                            _log.warn("unknown block: "
-                                      + _file.getName()
-                                      + "[" + lnr.getLineNumber() + "] "
-                                      + "'" + line + "'");
+                            _logger.warn("unknown block: "
+                                         + _file.getName()
+                                         + "[" + lnr.getLineNumber() + "] "
+                                         + "'" + line + "'");
                         }
                         if (ignore) {
                             continue;
@@ -346,16 +346,16 @@ public class Wdic {
                         while (idx1 != -1) {
                             idx2 = WdicUtil.indexOf(block, "]]", idx1+2);
                             if (idx2 < 0) {
-                                _log.warn("not found reference end tag: "
-                                          + _file.getName()
-                                          + "[" + lnr.getLineNumber() + "] "
-                                          + "'" + line + "'");
+                                _logger.warn("not found reference end tag: "
+                                             + _file.getName()
+                                             + "[" + lnr.getLineNumber() + "] "
+                                             + "'" + line + "'");
                                 break;
                             } else if (idx1+2 == idx2) {
-                                _log.warn("not found reference context: "
-                                          + _file.getName()
-                                          + "[" + lnr.getLineNumber() + "] "
-                                          + "'" + line + "'");
+                                _logger.warn("not found reference context: "
+                                             + _file.getName()
+                                             + "[" + lnr.getLineNumber() + "] "
+                                             + "'" + line + "'");
                             } else {
                                 String str = block.substring(idx1+2, idx2);
                                 if (str.charAt(0) == '<') {
@@ -388,9 +388,9 @@ public class Wdic {
                     item = null;
                 }
             }
-            _log.info("loaded " + _itemList.size() + " items");
+            _logger.info("loaded " + _itemList.size() + " items");
         } catch (IOException e) {
-            _log.fatal(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(lnr);
         }
