@@ -29,8 +29,8 @@ import org.apache.commons.io.filefilter.FileFilterUtils;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.CharUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.util.HexUtil;
 import fuku.xml2eb.CatalogInfo;
@@ -62,7 +62,7 @@ public class Wdic2Xml {
         "0x" + HexUtil.toHexString(CatalogInfo.TYPE_GENERAL, 2);
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** ベースディレクトリ */
     private File _basedir = null;
     /** WDICグループリスト */
@@ -111,7 +111,7 @@ public class Wdic2Xml {
      */
     public Wdic2Xml(File dir) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _basedir = dir;
     }
 
@@ -144,17 +144,17 @@ public class Wdic2Xml {
         subbook.setAttribute("dir", BOOK_DIR);
         subbook.setAttribute("type", BOOK_TYPE);
 
-        _log.info("create content node...");
+        _logger.info("create content node...");
         _makeContentNode(subbook);
-        _log.info("create graphic node...");
+        _logger.info("create graphic node...");
         _makeGraphicNode(subbook);
-        _log.info("create sound node...");
+        _logger.info("create sound node...");
         _makeSoundNode(subbook);
-        _log.info("create font node...");
+        _logger.info("create font node...");
         _makeFontNode(subbook);
 
         file = new File(_basedir, BOOK_XML);
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         XmlUtil.write(doc, file);
     }
 
@@ -172,7 +172,7 @@ public class Wdic2Xml {
             if (name.endsWith(".jpg")) {
                 File jpg = new File(plugin, name);
                 if (!jpg.exists()) {
-                    _log.error("file not found: " + jpg.getPath());
+                    _logger.error("file not found: " + jpg.getPath());
                 }
                 String path = FilenameUtils.concat(WDIC_PLUGIN_DIR, name);
                 _appendData(graphic, name, path, "jpg");
@@ -180,7 +180,7 @@ public class Wdic2Xml {
                 String bmpName = name + ".bmp";
                 File bmp = new File(plugin, bmpName);
                 if (!bmp.exists()) {
-                    _log.error("file not found: " + bmp.getPath());
+                    _logger.error("file not found: " + bmp.getPath());
                 }
                 String path = FilenameUtils.concat(WDIC_PLUGIN_DIR, bmpName);
                 _appendData(graphic, name, path, "bmp");
@@ -194,7 +194,7 @@ public class Wdic2Xml {
             String bmpName = name + ".50px.png.bmp";
             File bmp = new File(glyph, bmpName);
             if (!bmp.exists()) {
-                _log.error("file not found: " + bmp.getPath());
+                _logger.error("file not found: " + bmp.getPath());
             }
             String path = FilenameUtils.concat(WDIC_GLYPH_DIR, bmpName);
             _appendData(graphic, "glyph-"+name, path, "bmp");
@@ -206,7 +206,7 @@ public class Wdic2Xml {
             String name = _tableList.get(i) + ".bmp";
             File bmp = new File(table, name);
             if (!bmp.exists()) {
-                _log.error("file not found: " + bmp.getPath());
+                _logger.error("file not found: " + bmp.getPath());
             }
             String path = FilenameUtils.concat(WDIC_TABLE_DIR, name);
             _appendData(graphic, name, path, "bmp");
@@ -228,14 +228,14 @@ public class Wdic2Xml {
                 String wavName = name + ".wav";
                 File wav = new File(plugin, wavName);
                 if (!wav.exists()) {
-                    _log.error("file not found: " + wav.getPath());
+                    _logger.error("file not found: " + wav.getPath());
                 }
                 String path = FilenameUtils.concat(WDIC_PLUGIN_DIR, wavName);
                 _appendData(sound, name, path, "wav");
             } else if (name.endsWith(".mid")) {
                 File midi = new File(plugin, name);
                 if (!midi.exists()) {
-                    _log.error("file not found: " + midi.getPath());
+                    _logger.error("file not found: " + midi.getPath());
                 }
                 String path = FilenameUtils.concat(WDIC_PLUGIN_DIR, name);
                 _appendData(sound, name, path, "mid");
@@ -259,7 +259,7 @@ public class Wdic2Xml {
             String type = entry.getValue();
             File file = new File(gaiji, name + ".xbm");
             if (!file.exists()) {
-                _log.error("file not found: " + file.getPath());
+                _logger.error("file not found: " + file.getPath());
             }
             String path = FilenameUtils.concat(WDIC_GAIJI_DIR, file.getName());
             Element charElem = _appendElement(font, "char");
@@ -279,7 +279,7 @@ public class Wdic2Xml {
     private void _makeContentNode(Element subbook) {
         Element content = _appendElement(subbook, "content");
 
-        _log.info("create item node...");
+        _logger.info("create item node...");
         Collection<WdicGroup> groups = _groupList.getGroups();
         Iterator<WdicGroup> it = groups.iterator();
         while (it.hasNext()) {
@@ -298,10 +298,10 @@ public class Wdic2Xml {
         }
         _makeItemNode(content);
 
-        _log.info("create menu node...");
+        _logger.info("create menu node...");
         _makeMenuNode(content);
 
-        _log.info("create copyright node...");
+        _logger.info("create copyright node...");
         _makeCopyrightNode(content);
     }
 
@@ -318,7 +318,7 @@ public class Wdic2Xml {
         String partId = item.getWdic().getPartId();
 
         String head = item.getHead();
-        _log.debug("  [" + grpId + ":" + partId + "] " + head);
+        _logger.debug("  [" + grpId + ":" + partId + "] " + head);
         Element itemElem = _appendItem(content, "WDIC:" + grpId + ":" + head);
         Element headElem = _appendElement(itemElem, "head");
         _appendRawText(headElem, head + " 【" + grpName + "：" + partName + "】");
@@ -369,7 +369,7 @@ public class Wdic2Xml {
         }
 
         if (!wordAvail) {
-            _log.warn("word not defined: " + grpId + ":" + partId + ":" + head);
+            _logger.warn("word not defined: " + grpId + ":" + partId + ":" + head);
         }
 
         // 本文の登録
@@ -498,9 +498,7 @@ public class Wdic2Xml {
                 }
             } else {
                 indent -= ignoreTabs;
-                if (indent < 0) {
-                    indent = 0;
-                }
+                indent = Math.max(indent, 0);
                 if (block.startsWith("+ ")) {
                     // キー"-1"にこのブロックのインデント数を設定する
                     numMap.put(-1, indent);
@@ -649,8 +647,8 @@ public class Wdic2Xml {
                         table.add(block);
                     }
                     File dir = new File(_basedir, WDIC_TABLE_DIR);
-                    if (!dir.exists()) {
-                        dir.mkdirs();
+                    if (!dir.exists() && !dir.mkdirs()) {
+                        _logger.error("failed to create directories: " + dir.getPath());
                     }
                     String name = grpId + "_" + partId + "_" + item.getIndex() + "-" + tableNum;
                     File file = new File(dir, name + ".bmp");
@@ -659,8 +657,10 @@ public class Wdic2Xml {
                         try {
                             BmpUtil.write(img, file);
                         } catch (IOException e) {
-                            _log.error(e.getMessage(), e);
-                            file.delete();
+                            _logger.error(e.getMessage(), e);
+                            if (file.exists() && !file.delete()) {
+                                _logger.error("failed to delete file: " + file.getPath());
+                            }
                         } finally {
                             if (img != null) {
                                 img.flush();
@@ -688,8 +688,8 @@ public class Wdic2Xml {
                         table.add(block);
                     }
                     File dir = new File(_basedir, WDIC_TABLE_DIR);
-                    if (!dir.exists()) {
-                        dir.mkdirs();
+                    if (!dir.exists() && !dir.mkdirs()) {
+                        _logger.error("failed to create directories: " + dir.getPath());
                     }
                     String name = grpId + "_" + partId + "_" + item.getIndex() + "-" + tableNum;
                     File file = new File(dir, name + ".bmp");
@@ -698,8 +698,10 @@ public class Wdic2Xml {
                         try {
                             BmpUtil.write(img, file);
                         } catch (IOException e) {
-                            _log.error(e.getMessage(), e);
-                            file.delete();
+                            _logger.error(e.getMessage(), e);
+                            if (file.exists() && !file.delete()) {
+                                _logger.error("failed to delete file: " + file.getPath());
+                            }
                         } finally {
                             if (img != null) {
                                 img.flush();
@@ -847,7 +849,7 @@ public class Wdic2Xml {
         Map.Entry<String,Set<WdicItem>> entry;
 
         // 画像グラグイン
-        _log.debug("  graphic plugin");
+        _logger.debug("  graphic plugin");
         String[] ext = {".jpg", ".png"};
         int len = ext.length;
         for (int i=0; i<len; i++) {
@@ -892,7 +894,7 @@ public class Wdic2Xml {
         }
 
         // 音声プラグイン
-        _log.debug("  sound plugin");
+        _logger.debug("  sound plugin");
         ext = new String[]{".mp3", ".ogg", ".mid"};
         len = ext.length;
         for (int i=0; i<len; i++) {
@@ -937,7 +939,7 @@ public class Wdic2Xml {
         }
 
         // その他のプラグイン
-        _log.debug("  document plugin");
+        _logger.debug("  document plugin");
         File plugin = new File(_basedir, WDIC_PLUGIN_DIR);
         ext = new String[]{".jpg", ".png", ".mp3", ".ogg", ".mid"};
         len = ext.length;
@@ -955,7 +957,7 @@ public class Wdic2Xml {
             if (add) {
                 File file = new File(plugin, name);
                 if (!file.exists()) {
-                    _log.error("file not found: " + file.getPath());
+                    _logger.error("file not found: " + file.getPath());
                     continue;
                 }
                 Element itemElem = _appendItem(content, "PLUGIN:" + name);
@@ -997,7 +999,7 @@ public class Wdic2Xml {
                         _appendNewLine(indentElem);
                     }
                 } catch (IOException e) {
-                    _log.error(e.getMessage(), e);
+                    _logger.error(e.getMessage(), e);
                 }
             }
         }
@@ -1060,21 +1062,21 @@ public class Wdic2Xml {
         _appendRawText(refElem, "文書プラグイン一覧");
         _appendNewLine(layerElem);
 
-        _log.debug("  manual");
+        _logger.debug("  manual");
         _createManualLayer(menu);
-        _log.debug("  bibliography");
+        _logger.debug("  bibliography");
         _createBibliographyLayer(menu);
-        _log.debug("  directory");
+        _logger.debug("  directory");
         _createDirectoryLayer(menu);
-        _log.debug("  group");
+        _logger.debug("  group");
         _createGroupLayer(menu);
-        _log.debug("  plugin list");
+        _logger.debug("  plugin list");
         _createPluginLayer(menu);
-        _log.debug("  graphic list");
+        _logger.debug("  graphic list");
         _createImageLayer(menu);
-        _log.debug("  sound list");
+        _logger.debug("  sound list");
         _createSoundLayer(menu);
-        _log.debug("  document list");
+        _logger.debug("  document list");
         _createTextLayer(menu);
     }
 
@@ -1370,7 +1372,7 @@ public class Wdic2Xml {
                 _appendRawText(layerElem, name);
                 List<String> yomiList = item.getYomi();
                 if (yomiList.isEmpty()) {
-                    _log.info("yomi not defined: " + grpId + ":" + partId + ":" + item.getHead());
+                    _logger.info("yomi not defined: " + grpId + ":" + partId + ":" + item.getHead());
                 } else {
                     String yomi = yomiList.get(0);
                     _appendText(item, layerElem, " [" + yomi + "]");
@@ -1389,7 +1391,7 @@ public class Wdic2Xml {
                 _appendRawText(refElem, name);
                 List<String> yomiList = item.getYomi();
                 if (yomiList.isEmpty()) {
-                    _log.info("yomi not defined: " + grpId + ":" + partId + ":" + item.getHead());
+                    _logger.info("yomi not defined: " + grpId + ":" + partId + ":" + item.getHead());
                 } else {
                     String yomi = yomiList.get(0);
                     _appendText(item, layerElem, " [" + yomi + "]");
@@ -1834,14 +1836,14 @@ public class Wdic2Xml {
                                     }
                                     _appendText(item, refElem, name, linkBlock);
                                 } else {
-                                    _log.error("undefined word: " + gid + "/" + refid);
+                                    _logger.error("undefined word: " + gid + "/" + refid);
                                     if (linkBlock) {
                                         name = name + " 《" + gname + "》";
                                     }
                                     _appendText(item, node, name, linkBlock);
                                 }
                             } else {
-                                _log.error("undefined group: " + gid);
+                                _logger.error("undefined group: " + gid);
                                 _appendText(item, node, name, linkBlock);
                             }
                         }
@@ -1878,7 +1880,7 @@ public class Wdic2Xml {
 
             int idx = WdicUtil.indexOf(str, ";", i+1);
             if (idx < 0) {
-                _log.error("unexpected format: " + str);
+                _logger.error("unexpected format: " + str);
                 buf.append(ch);
                 continue;
             }
@@ -1931,7 +1933,7 @@ public class Wdic2Xml {
                     int codePoint = Integer.parseInt(code, 16);
                     buf.appendCodePoint(codePoint);
                 } catch (Exception e) {
-                    _log.error("unknown character code: " + code);
+                    _logger.error("unknown character code: " + code);
                 }
             } else if ("sup".equals(name) || "sub".equals(name)) {
                 _appendRawText(node, buf.toString());
@@ -1991,8 +1993,8 @@ public class Wdic2Xml {
                     String hex = HexUtil.toHexString(codePoint, 6);
                     String fontname = "U" + hex + "-OL";
                     File dir = new File(_basedir, WDIC_GAIJI_DIR);
-                    if (!dir.exists()) {
-                        dir.mkdirs();
+                    if (!dir.exists() && !dir.mkdirs()) {
+                        _logger.error("failed to create directories: " + dir.getPath());
                     }
                     File file = new File(dir, fontname + ".xbm");
                     if (!file.exists()) {
@@ -2000,8 +2002,10 @@ public class Wdic2Xml {
                         try {
                             FontUtil.writeXbm(img, file);
                         } catch (IOException e) {
-                            _log.error(e.getMessage(), e);
-                            file.delete();
+                            _logger.error(e.getMessage(), e);
+                            if (file.exists() && !file.delete()) {
+                                _logger.error("failed to delete file: " + file.getPath());
+                            }
                         } finally {
                             if (img != null) {
                                 img.flush();
@@ -2025,8 +2029,8 @@ public class Wdic2Xml {
                     String hex = HexUtil.toHexString(codePoint, 6);
                     String fontname = "U" + hex + "-UL";
                     File dir = new File(_basedir, WDIC_GAIJI_DIR);
-                    if (!dir.exists()) {
-                        dir.mkdirs();
+                    if (!dir.exists() && !dir.mkdirs()) {
+                        _logger.error("failed to create directories: " + dir.getPath());
                     }
                     File file = new File(dir, fontname + ".xbm");
                     if (!file.exists()) {
@@ -2034,8 +2038,10 @@ public class Wdic2Xml {
                         try {
                             FontUtil.writeXbm(img, file);
                         } catch (IOException e) {
-                            _log.error(e.getMessage(), e);
-                            file.delete();
+                            _logger.error(e.getMessage(), e);
+                            if (file.exists() && !file.delete()) {
+                                _logger.error("failed to delete file: " + file.getPath());
+                            }
                         } finally {
                             if (img != null) {
                                 img.flush();
@@ -2059,8 +2065,8 @@ public class Wdic2Xml {
                     String hex = HexUtil.toHexString(codePoint, 6);
                     String fontname = "U" + hex + "-LT";
                     File dir = new File(_basedir, WDIC_GAIJI_DIR);
-                    if (!dir.exists()) {
-                        dir.mkdirs();
+                    if (!dir.exists() && !dir.mkdirs()) {
+                        _logger.error("failed to create directories: " + dir.getPath());
                     }
                     File file = new File(dir, fontname + ".xbm");
                     if (!file.exists()) {
@@ -2068,8 +2074,10 @@ public class Wdic2Xml {
                         try {
                             FontUtil.writeXbm(img, file);
                         } catch (IOException e) {
-                            _log.error(e.getMessage(), e);
-                            file.delete();
+                            _logger.error(e.getMessage(), e);
+                            if (file.exists() && !file.delete()) {
+                                _logger.error("failed to delete file: " + file.getPath());
+                            }
                         } finally {
                             if (img != null) {
                                 img.flush();
@@ -2087,23 +2095,23 @@ public class Wdic2Xml {
                 _appendRawText(node, buf.toString());
                 buf.delete(0, buf.length());
                 buf.append(param.get(0));
-//                 if (param.size() > 1) {
-//                     String type = param.get(1);
-//                     if ("JC".equals(type)) {
-//                         buf.append("[ユリウス歴]");
-//                     } else if ("GC".equals(type)) {
-//                         buf.append("[グレゴリオ歴]");
-//                     } else if ("LC".equals(type)) {
-//                         buf.append("[太陰太陽歴]");
-//                     } else {
-//                         _log.error("unknown function parameter: " + itemId + " [" + name + ":" + type + "]");
-//                     }
-//                 }
+                // if (param.size() > 1) {
+                //     String type = param.get(1);
+                //     if ("JC".equals(type)) {
+                //         buf.append("[ユリウス歴]");
+                //     } else if ("GC".equals(type)) {
+                //         buf.append("[グレゴリオ歴]");
+                //     } else if ("LC".equals(type)) {
+                //         buf.append("[太陰太陽歴]");
+                //     } else {
+                //         _logger.error("unknown function parameter: " + itemId + " [" + name + ":" + type + "]");
+                //     }
+                // }
                 _appendText(item, node, buf.toString(), linkBlock);
                 buf.delete(0, buf.length());
             } else {
                 if (!"unit".equals(name)) {
-                    _log.error("unknown function name: " + itemId + " [" + name + "]");
+                    _logger.error("unknown function name: " + itemId + " [" + name + "]");
                 }
                 _appendRawText(node, buf.toString());
                 buf.delete(0, buf.length());
@@ -2171,8 +2179,8 @@ public class Wdic2Xml {
                     }
                     String name = buf.toString() + "-N";
                     File dir = new File(_basedir, WDIC_GAIJI_DIR);
-                    if (!dir.exists()) {
-                        dir.mkdirs();
+                    if (!dir.exists() && !dir.mkdirs()) {
+                        _logger.error("failed to create directories: " + dir.getPath());
                     }
                     String[] files =
                         dir.list(FileFilterUtils.andFileFilter(
@@ -2180,13 +2188,13 @@ public class Wdic2Xml {
                                      FileFilterUtils.suffixFileFilter(".xbm")));
                     if (ArrayUtils.isEmpty(files)) {
                         if (unicodeBlock == null) {
-                            _log.info("unsupported characters:"
-                                      + " '" + s + "'"
-                                      + " UNKNOWN_UNICODE_BLOCK");
+                            _logger.info("unsupported characters:"
+                                         + " '" + s + "'"
+                                         + " UNKNOWN_UNICODE_BLOCK");
                         } else {
-                            _log.info("unsupported characters:"
-                                      + " '" + s + "'"
-                                      + " " + unicodeBlock.toString());
+                            _logger.info("unsupported characters:"
+                                         + " '" + s + "'"
+                                         + " " + unicodeBlock.toString());
                         }
                         BufferedImage img = WdicUtil.toImage(s);
                         int height = img.getHeight();
@@ -2199,8 +2207,10 @@ public class Wdic2Xml {
                             try {
                                 FontUtil.writeXbm(b[i], width, height, file);
                             } catch (IOException e) {
-                                _log.error(e.getMessage(), e);
-                                file.delete();
+                                _logger.error(e.getMessage(), e);
+                                if (file.exists() && !file.delete()) {
+                                    _logger.error("failed to delete file: " + file.getPath());
+                                }
                             }
                         }
                     } else {
@@ -2217,28 +2227,30 @@ public class Wdic2Xml {
                     String hex = HexUtil.toHexString(codePoint, 6);
                     String name = "U" + hex;
                     File dir = new File(_basedir, WDIC_GAIJI_DIR);
-                    if (!dir.exists()) {
-                        dir.mkdirs();
+                    if (!dir.exists() && !dir.mkdirs()) {
+                        _logger.error("failed to create directories: " + dir.getPath());
                     }
                     File file = new File(dir, name + ".xbm");
                     if (!file.exists()) {
                         String s = String.valueOf(Character.toChars(codePoint));
                         if (unicodeBlock == null) {
-                            _log.info("unsupported characters:"
-                                      + " '" + s + "'"
-                                      + " UNKNOWN_UNICODE_BLOCK");
+                            _logger.info("unsupported characters:"
+                                         + " '" + s + "'"
+                                         + " UNKNOWN_UNICODE_BLOCK");
                         } else {
-                            _log.info("unsupported character:"
-                                      + " [U+" + hex + "]"
-                                      + " '" + s + "'"
-                                      + " " + unicodeBlock.toString());
+                            _logger.info("unsupported character:"
+                                         + " [U+" + hex + "]"
+                                         + " '" + s + "'"
+                                         + " " + unicodeBlock.toString());
                         }
                         BufferedImage img = WdicUtil.toImage(codePoint);
                         try {
                             FontUtil.writeXbm(img, file);
                         } catch (IOException e) {
-                            _log.error(e.getMessage(), e);
-                            file.delete();
+                            _logger.error(e.getMessage(), e);
+                            if (file.exists() && !file.delete()) {
+                                _logger.error("failed to delete file: " + file.getPath());
+                            }
                         } finally {
                             if (img != null) {
                                 img.flush();
