@@ -10,8 +10,8 @@ import java.util.regex.Pattern;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.LineIterator;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * 基礎文献クラス。
@@ -27,7 +27,7 @@ public class WdicBib {
     private static final Pattern SEC_PATTERN = Pattern.compile("^-+\\s■\\s(\\S*)\\s■\\s-+$");
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** マニュアルファイル */
     private File _file = null;
     /** 基礎文献 */
@@ -41,7 +41,7 @@ public class WdicBib {
      */
     public WdicBib(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _file = file;
         _bibList = new ArrayList<String>();
         _load();
@@ -62,7 +62,7 @@ public class WdicBib {
      *
      */
     private void _load() {
-        _log.info("load file: " + _file.getPath());
+        _logger.info("load file: " + _file.getPath());
         LineIterator it = null;
         try {
             it = FileUtils.lineIterator(_file, ENCODING);
@@ -77,7 +77,7 @@ public class WdicBib {
                 }
             }
         } catch (IOException e) {
-            _log.fatal(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             LineIterator.closeQuietly(it);
         }
