@@ -11,8 +11,8 @@ import java.util.Map;
 
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.LineIterator;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * 分類リストクラス。
@@ -25,7 +25,7 @@ public class WdicDirList {
     private static final String ENCODING = "UTF-8";
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** 分類リストファイル */
     private File _file = null;
     /** 分類マップ */
@@ -41,7 +41,7 @@ public class WdicDirList {
      */
     public WdicDirList(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _file = file;
         _map = new LinkedHashMap<String,String>();
         _alias = new HashMap<String,String>();
@@ -110,7 +110,7 @@ public class WdicDirList {
     private void _load() {
         LineIterator it = null;
         try {
-            _log.info("load file: " + _file.getPath());
+            _logger.info("load file: " + _file.getPath());
             it = FileUtils.lineIterator(_file, ENCODING);
             while (it.hasNext()) {
                 String line = WdicUtil.sanitize(it.nextLine());
@@ -122,11 +122,11 @@ public class WdicDirList {
                 } else if (n == 2) {
                     _map.put(item[0], item[1]);
                 } else {
-                    _log.warn("too many items in line: " + line);
+                    _logger.warn("too many items in line: " + line);
                 }
             }
         } catch (IOException e) {
-            _log.fatal(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             LineIterator.closeQuietly(it);
         }
