@@ -11,8 +11,8 @@ import java.util.regex.Pattern;
 
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.LineIterator;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * 辞書グループクラス。
@@ -25,7 +25,7 @@ public class WdicGroup {
     private static final String ENCODING = "UTF-8";
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** 辞書グループリスト */
     private WdicGroupList _groupList = null;
     /** 辞書グループファイル */
@@ -49,7 +49,7 @@ public class WdicGroup {
      */
     public WdicGroup(WdicGroupList groupList, String id, File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _groupList = groupList;
         _groupId = id;
         _file = file;
@@ -193,7 +193,7 @@ public class WdicGroup {
      *
      */
     private void _load() {
-        _log.info("load file: " + _file.getPath());
+        _logger.info("load file: " + _file.getPath());
 
         File dir = _file.getParentFile();
         Pattern attrPattern = Pattern.compile("^(\\S+)\\s*=\\s*(.+)$");
@@ -250,7 +250,7 @@ public class WdicGroup {
                 }
             }
         } catch (IOException e) {
-            _log.fatal(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             LineIterator.closeQuietly(it);
         }
