@@ -15,8 +15,8 @@ import java.util.regex.Pattern;
 
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.LineIterator;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * 辞書グループリストクラス。
@@ -29,7 +29,7 @@ public class WdicGroupList {
     private static final String ENCODING = "UTF-8";
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** グループリストファイル */
     private File _file = null;
     /** 辞書の名称 */
@@ -47,7 +47,7 @@ public class WdicGroupList {
      */
     public WdicGroupList(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _file = file;
         _map = new LinkedHashMap<String,WdicGroup>();
         _load();
@@ -126,7 +126,7 @@ public class WdicGroupList {
      *
      */
     private void _load() {
-        _log.info("load file: " + _file.getPath());
+        _logger.info("load file: " + _file.getPath());
 
         Pattern attrPattern = Pattern.compile("^(\\S+)\\s*=\\s*(.+)$");
 
@@ -181,7 +181,7 @@ public class WdicGroupList {
                 }
             }
         } catch (IOException e) {
-            _log.fatal(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             LineIterator.closeQuietly(it);
         }
