@@ -13,8 +13,8 @@ import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.LineIterator;
 import org.apache.commons.lang.CharUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * マニュアルクラス。
@@ -30,7 +30,7 @@ public class WdicMan {
     private static final Pattern SEC_PATTERN = Pattern.compile("^-+\\s\\u25a0\\s(\\S*)\\s\\u25a0\\s-+$");
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** マニュアルファイル */
     private File _file = null;
     /** 著作権情報 */
@@ -46,7 +46,7 @@ public class WdicMan {
      */
     public WdicMan(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _file = file;
         _copyList = new ArrayList<String>();
         _map = new LinkedHashMap<String,List<String>>();
@@ -91,7 +91,7 @@ public class WdicMan {
      *
      */
     private void _load() {
-        _log.info("load file: " + _file.getPath());
+        _logger.info("load file: " + _file.getPath());
         LineIterator it = null;
         try {
             it = FileUtils.lineIterator(_file, ENCODING);
@@ -134,7 +134,7 @@ public class WdicMan {
                 }
             }
         } catch (IOException e) {
-            _log.fatal(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             LineIterator.closeQuietly(it);
         }
@@ -461,7 +461,7 @@ public class WdicMan {
                         str = "\u25a0 " + str.substring(1);
                     }
                 } else {
-                    if (str.indexOf(" ") > 0) {
+                    if (str.indexOf(" ") >= 0) {
                         if (buf.length() > 0) {
                             list.add(buf.toString());
                             buf.delete(0, buf.length());
