@@ -12,8 +12,8 @@ import java.util.ArrayList;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.CharUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.util.HexUtil;
 import fuku.xml2eb.util.WaitImageObserver;
@@ -36,7 +36,7 @@ public class WdicTableItem {
     public static final int RIGHT = 2;
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** 辞書項目 */
     private WdicItem _item = null;
 
@@ -80,7 +80,7 @@ public class WdicTableItem {
      */
     public WdicTableItem(WdicItem item, boolean header, String data) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _item = item;
         _header = header;
         if (_header) {
@@ -135,7 +135,7 @@ public class WdicTableItem {
                             String grpId = _item.getWdic().getGroupId();
                             String partId = _item.getWdic().getPartId();
                             String id = grpId + ":" + partId + ":" + _item.getHead();
-                            _log.warn("unexped table format: " + id + " '" + data + "'");
+                            _logger.warn("unexpected table format: " + id + " '" + data + "'");
                             _content = str;
                             break;
                         }
@@ -517,10 +517,10 @@ public class WdicTableItem {
                                 if (wdic != null) {
                                     refid = "WDIC:" + gid + ":" + head;
                                 } else {
-                                    _log.error("undefined word: " + gid + "/" + head);
+                                    _logger.error("undefined word: " + gid + "/" + head);
                                 }
                             } else {
-                                _log.error("undefined group: " + gid);
+                                _logger.error("undefined group: " + gid);
                             }
                         }
                         if (buf.length() > 0) {
@@ -534,6 +534,7 @@ public class WdicTableItem {
                         g2.setColor(origColor);
                         i = idx2 + 1;
                         if (StringUtils.isNotBlank(refid)) {
+                            // クリック領域
                             FontMetrics fm = g2.getFontMetrics();
                             int h = fm.getAscent() + fm.getDescent();
                             Rectangle rect = new Rectangle(start, y, x, y+h);
@@ -570,7 +571,7 @@ public class WdicTableItem {
 
             int idx = WdicUtil.indexOf(str, ";", i+1);
             if (idx < 0) {
-                _log.error("unexpected format: " + str);
+                _logger.error("unexpected format: " + str);
                 buf.append(ch);
                 continue;
             }
@@ -627,7 +628,7 @@ public class WdicTableItem {
                     int codePoint = Integer.parseInt(code, 16);
                     buf.appendCodePoint(codePoint);
                 } catch (Exception e) {
-                    _log.error("unknown character code: " + code);
+                    _logger.error("unknown character code: " + code);
                 }
             } else if ("sup".equals(name)) {
                 Font origFont = g2.getFont();
@@ -707,7 +708,7 @@ public class WdicTableItem {
             } else {
                 if (!"unit".equals(name)
                     && !"date".equals(name) && !"dt".equals(name)) {
-                    _log.error("unknown function name: " + name);
+                    _logger.error("unknown function name: " + name);
                 }
                 x = _drawText(g2, param.get(0), x, y);
             }
@@ -756,19 +757,19 @@ public class WdicTableItem {
                         style = "ITALIC";
                     }
                     if (unicodeBlock == null) {
-                        _log.warn("unavailable display font: [" + code + "]"
-                                  + " block:UNKNOWN_UNICODE_BLOCK"
-                                  + " font:" + font.getName()
-                                  + " style:" + style
-                                  + " size:" + font.getSize()
-                                  + " (using plain font)");
+                        _logger.warn("unavailable display font: [" + code + "]"
+                                     + " block:UNKNOWN_UNICODE_BLOCK"
+                                     + " font:" + font.getName()
+                                     + " style:" + style
+                                     + " size:" + font.getSize()
+                                     + " (using plain font)");
                     } else {
-                        _log.warn("unavailable display font: [" + code + "]"
-                                  + " block:" + unicodeBlock.toString()
-                                  + " font:" + font.getName()
-                                  + " style:" + style
-                                  + " size:" + font.getSize()
-                                  + " (using plain font)");
+                        _logger.warn("unavailable display font: [" + code + "]"
+                                     + " block:" + unicodeBlock.toString()
+                                     + " font:" + font.getName()
+                                     + " style:" + style
+                                     + " size:" + font.getSize()
+                                     + " (using plain font)");
                     }
                     font = plainFont;
                 }
@@ -796,11 +797,11 @@ public class WdicTableItem {
                     // 表示できない文字は'?'を描画
                     String code = "U+" + HexUtil.toHexString(codePoint, 6);
                     if (unicodeBlock == null) {
-                        _log.warn("unavailable display font: [" + code + "]"
-                                  + " UNKNOWN_UNICODE_BLOCK");
+                        _logger.warn("unavailable display font: [" + code + "]"
+                                     + " UNKNOWN_UNICODE_BLOCK");
                     } else {
-                        _log.warn("unavailable display font: [" + code + "]"
-                                  + " " + unicodeBlock.toString());
+                        _logger.warn("unavailable display font: [" + code + "]"
+                                     + " " + unicodeBlock.toString());
                     }
                     codePoint = '?';
                     drawStr = String.valueOf(Character.toChars(codePoint));
