@@ -19,8 +19,8 @@ import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.CharUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.util.HexUtil;
 import fuku.xml2eb.util.FontUtil;
@@ -34,7 +34,7 @@ import fuku.xml2eb.util.UnicodeUtil;
 public class WdicUtil {
 
     /** ログ */
-    private static final Log _log = LogFactory.getLog(WdicUtil.class);
+    private static final Logger _logger = LoggerFactory.getLogger(WdicUtil.class);
     /** 文字参照マップ */
     private static final Map<String,String> _charMap = new HashMap<String,String>();
 
@@ -73,7 +73,7 @@ public class WdicUtil {
                 fis = new FileInputStream(file);
                 prop.load(fis, "UTF-8");
             } catch (IOException e) {
-                _log.warn(e.getMessage(), e);
+                _logger.warn(e.getMessage(), e);
             } finally {
                 IOUtils.closeQuietly(fis);
             }
@@ -95,7 +95,7 @@ public class WdicUtil {
                             fontMap.put(family[i], font);
                             fontList.add(font);
                         } else {
-                            _log.error("unknown font name: " + family[i]);
+                            _logger.error("unknown font name: " + family[i]);
                         }
                     } else {
                         fontList.add(font);
@@ -114,7 +114,7 @@ public class WdicUtil {
                                 Character.UnicodeBlock.forName(key);
                             _fontBlockMap.put(unicodeBlock, fonts);
                         } catch (IllegalArgumentException e2) {
-                            _log.error("unknown UnicodeBlock: " + key);
+                            _logger.error("unknown UnicodeBlock: " + key);
                         }
                     }
                 }
@@ -130,7 +130,7 @@ public class WdicUtil {
                 fis = new FileInputStream(file);
                 prop.load(fis, "UTF-8");
             } catch (IOException e) {
-                _log.warn(e.getMessage(), e);
+                _logger.warn(e.getMessage(), e);
             } finally {
                 IOUtils.closeQuietly(fis);
             }
@@ -292,7 +292,7 @@ public class WdicUtil {
 
             int idx = WdicUtil.indexOf(str, ";", i+1);
             if (idx < 0) {
-                _log.error("unexpected format: " + str);
+                _logger.error("unexpected format: " + str);
                 buf.append(ch);
                 continue;
             }
@@ -345,11 +345,11 @@ public class WdicUtil {
                     codePoint = Integer.parseInt(code, 16);
                     buf.appendCodePoint(codePoint);
                 } catch (NumberFormatException e) {
-                    _log.error("unknown character code: " + code);
+                    _logger.error("unknown character code: " + code);
                 }
             } else {
                 if (!"sup".equals(name) && !"sub".equals(name)) {
-                    _log.error("unknown function name: " + name);
+                    _logger.error("unknown function name: " + name);
                 }
                 buf.append(unescape(param.get(0)));
             }
@@ -368,7 +368,7 @@ public class WdicUtil {
         if (ch != null) {
             return ch;
         }
-        _log.error("unknown character reference: " + name);
+        _logger.error("unknown character reference: " + name);
         return name;
     }
 
@@ -472,11 +472,11 @@ public class WdicUtil {
                 // 表示できない文字は'?'を描画
                 String code = "U+" + HexUtil.toHexString(codePoint, 6);
                 if (unicodeBlock == null) {
-                    _log.warn("unavailable display font: [" + code + "]"
-                              + " UNKNOWN_UNICODE_BLOCK");
+                    _logger.warn("unavailable display font: [" + code + "]"
+                                 + " UNKNOWN_UNICODE_BLOCK");
                 } else {
-                    _log.warn("unavailable display font: [" + code + "]"
-                              + " " + unicodeBlock.toString());
+                    _logger.warn("unavailable display font: [" + code + "]"
+                                 + " " + unicodeBlock.toString());
                 }
                 codePoint = '?';
                 font = getFont(codePoint);
@@ -579,11 +579,11 @@ public class WdicUtil {
 
         String code = "U+" + HexUtil.toHexString(codePoint, 6);
         if (unicodeBlock == null) {
-            _log.info("undefined font: [" + code + "]"
-                      + " UNKNOWN_UNICODE_BLOCK");
+            _logger.info("undefined font: [" + code + "]"
+                         + " UNKNOWN_UNICODE_BLOCK");
         } else {
-            _log.info("undefined font: [" + code + "]"
-                      + " " + unicodeBlock.toString());
+            _logger.info("undefined font: [" + code + "]"
+                         + " " + unicodeBlock.toString());
         }
 
         // デフォルトフォントから検索
