@@ -19,8 +19,8 @@ import org.w3c.dom.NodeList;
 import org.w3c.dom.Text;
 
 import org.apache.commons.io.FilenameUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.util.HexUtil;
 import fuku.xml2eb.CatalogInfo;
@@ -49,7 +49,7 @@ public class ZipCode2Xml {
         "0x" + HexUtil.toHexString(CatalogInfo.TYPE_GENERAL, 2);
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** ベースディレクトリ */
     private File _basedir = null;
     /** 全国一括郵便番号 */
@@ -94,7 +94,7 @@ public class ZipCode2Xml {
      */
     public ZipCode2Xml(File dir) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _basedir = dir;
     }
 
@@ -119,7 +119,7 @@ public class ZipCode2Xml {
         Element book = doc.createElement("book");
         doc.appendChild(book);
 
-        _log.info("create zipcode subbook...");
+        _logger.info("create zipcode subbook...");
         _gaijiMap = _kenGaijiMap;
         Element subbook = _appendElement(book, "subbook");
         subbook.setAttribute("title", BOOK_TITLE1);
@@ -131,7 +131,7 @@ public class ZipCode2Xml {
         _makeKenCopyrightNode(content);
         _makeFontNode(subbook);
 
-        _log.info("create jigyosyo subbook...");
+        _logger.info("create jigyosyo subbook...");
         _gaijiMap = _jigyosyoGaijiMap;
         subbook = _appendElement(book, "subbook");
         subbook.setAttribute("title", BOOK_TITLE2);
@@ -144,7 +144,7 @@ public class ZipCode2Xml {
         _makeFontNode(subbook);
 
         file = new File(_basedir, BOOK_XML);
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         XmlUtil.write(doc, file);
     }
 
@@ -491,7 +491,7 @@ public class ZipCode2Xml {
             String type = entry.getValue();
             File file = new File(gaiji, name + ".xbm");
             if (!file.exists()) {
-                _log.error("file not found: " + file.getPath());
+                _logger.error("file not found: " + file.getPath());
             }
             String path = FilenameUtils.concat(GAIJI_DIR, file.getName());
             Element charElem = _appendElement(font, "char");
@@ -601,22 +601,24 @@ public class ZipCode2Xml {
                 String hex = HexUtil.toHexString(codePoint, 6);
                 String name = "U" + hex;
                 File dir = new File(_basedir, GAIJI_DIR);
-                if (!dir.exists()) {
-                    dir.mkdirs();
+                if (!dir.exists() && !dir.mkdirs()) {
+                    _logger.error("failed to create directories: " + dir.getPath());
                 }
                 File file = new File(dir, name + ".xbm");
                 if (!file.exists()) {
                     String s = String.valueOf(Character.toChars(codePoint));
-                    _log.info("unsupported character:"
-                              + " [U+" + hex + "]"
-                              + " '" + s + "'"
-                              + " " + unicodeBlock.toString());
+                    _logger.info("unsupported character:"
+                                 + " [U+" + hex + "]"
+                                 + " '" + s + "'"
+                                 + " " + unicodeBlock.toString());
                     BufferedImage img = ZipCodeUtil.toImage(codePoint);
                     try {
                         FontUtil.writeXbm(img, file);
                     } catch (IOException e) {
-                        _log.error(e.getMessage(), e);
-                        file.delete();
+                        _logger.error(e.getMessage(), e);
+                        if (file.exists() && !file.delete()) {
+                            _logger.error("failed to delete file: " + file.getPath());
+                        }
                     } finally {
                         if (img != null) {
                             img.flush();
