@@ -16,8 +16,8 @@ import java.util.LinkedHashMap;
 
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.text.StrTokenizer;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.xml2eb.util.UnicodeUtil;
 
@@ -31,7 +31,7 @@ public class ZipCodeJigyosyo {
     private static final String ENCODING = "MS932";
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** ファイル */
     private File _file = null;
     /** 項目リスト */
@@ -45,7 +45,7 @@ public class ZipCodeJigyosyo {
      */
     public ZipCodeJigyosyo(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _file = file;
         _load();
     }
@@ -145,7 +145,7 @@ public class ZipCodeJigyosyo {
      *
      */
     private void _load() {
-        _log.info("load file: " + _file.getPath());
+        _logger.info("load file: " + _file.getPath());
         LineNumberReader lnr = null;
         try {
             Charset cs = Charset.forName(ENCODING);
@@ -161,9 +161,9 @@ public class ZipCodeJigyosyo {
                 StrTokenizer st = StrTokenizer.getCSVInstance(line);
                 int n = st.size();
                 if (n != 13) {
-                    _log.error("unknown tokens count: "
-                               + _file.getName()
-                               + "[" +lnr.getLineNumber() + "] " + n);
+                    _logger.error("unknown tokens count: "
+                                  + _file.getName()
+                                  + "[" +lnr.getLineNumber() + "] " + n);
                     continue;
                 }
                 String[] tokens = st.getTokenArray();
@@ -173,9 +173,9 @@ public class ZipCodeJigyosyo {
                                      tokens[10], tokens[11]);
                 _itemList.add(item);
             }
-            _log.info("loaded " + _itemList.size() + " items");
+            _logger.info("loaded " + _itemList.size() + " items");
         } catch (IOException e) {
-            _log.fatal(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(lnr);
         }
