@@ -17,8 +17,8 @@ import java.util.LinkedHashMap;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.text.StrTokenizer;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.xml2eb.util.UnicodeUtil;
 
@@ -32,7 +32,7 @@ public class ZipCodeKen {
     private static final String ENCODING = "MS932";
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** ファイル */
     private File _file = null;
     /** 項目リスト */
@@ -46,7 +46,7 @@ public class ZipCodeKen {
      */
     public ZipCodeKen(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _file = file;
         _load();
     }
@@ -127,7 +127,7 @@ public class ZipCodeKen {
      *
      */
     private void _load() {
-        _log.info("load file: " + _file.getPath());
+        _logger.info("load file: " + _file.getPath());
         LineNumberReader lnr = null;
         try {
             Charset cs = Charset.forName(ENCODING);
@@ -144,9 +144,9 @@ public class ZipCodeKen {
                 StrTokenizer st = StrTokenizer.getCSVInstance(line);
                 int n = st.size();
                 if (n != 15) {
-                    _log.error("unexpected token count: "
-                               + _file.getName()
-                               + "[" +lnr.getLineNumber() + "] " + n);
+                    _logger.error("unexpected token count: "
+                                  + _file.getName()
+                                  + "[" +lnr.getLineNumber() + "] " + n);
                     continue;
                 }
                 String[] tokens = st.getTokenArray();
@@ -158,9 +158,9 @@ public class ZipCodeKen {
                     }
                 }
                 if (empty != -1) {
-                    _log.warn("empty token found: "
-                              + _file.getName()
-                              + "[" +lnr.getLineNumber() + "] " + empty);
+                    _logger.warn("empty token found: "
+                                 + _file.getName()
+                                 + "[" +lnr.getLineNumber() + "] " + empty);
                     continue;
                 }
                 if (item != null && !item.isClosed()) {
@@ -172,9 +172,9 @@ public class ZipCodeKen {
                     _itemList.add(item);
                 }
             }
-            _log.info("loaded " + _itemList.size() + " items");
+            _logger.info("loaded " + _itemList.size() + " items");
         } catch (IOException e) {
-            _log.fatal(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(lnr);
         }
