@@ -3,8 +3,8 @@ package fuku.xml2eb.converter.zipcode;
 import java.awt.Font;
 import java.awt.image.BufferedImage;
 
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.util.HexUtil;
 import fuku.xml2eb.util.FontUtil;
@@ -17,7 +17,7 @@ import fuku.xml2eb.util.FontUtil;
 public class ZipCodeUtil {
 
     /** ログ */
-    private static final Log _log = LogFactory.getLog(ZipCodeUtil.class);
+    private static final Logger _logger = LoggerFactory.getLogger(ZipCodeUtil.class);
 
     /** 論理フォント */
     private static final Font[] LOGICAL_FONT = {
@@ -58,8 +58,8 @@ public class ZipCodeUtil {
             // 表示できない文字は'?'を描画
             Character.UnicodeBlock unicodeBlock = Character.UnicodeBlock.of(codePoint);
             String code = "U+" + HexUtil.toHexString(codePoint, 6);
-            _log.warn("unavailable display font: [" + code + "]"
-                      + " " + unicodeBlock.toString());
+            _logger.warn("unavailable display font: [" + code + "]"
+                         + " " + unicodeBlock.toString());
             codePoint = '?';
             font = getFont(codePoint);
             if ("narrow".equals(type)) {
