@@ -48,7 +48,10 @@ public class Book {
         "#E#N#G!?#J#A#N!J!\\#F#R#E!K",
         // Japanese-English-Spanish Jiten (YRRS-060)
         // (ＥＮＧ／ＪＡＮ（＋ＳＰＡ）)
-        "#E#N#G!?#J#A#N!J!\\#S#P#A!K"
+        "#E#N#G!?#J#A#N!J!\\#S#P#A!K",
+        // Panasonic KX-EBP2 accessories.
+        // (プロシード英和・和英辞典)
+        "%W%m%7!<%I1QOB!&OB1Q<-E5"
     };
 
 
