@@ -2,8 +2,8 @@ package fuku.eb4j;
 
 import java.io.UnsupportedEncodingException;
 
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.io.EBFile;
 import fuku.eb4j.io.BookInputStream;
@@ -40,7 +40,7 @@ public class SingleWordSearcher implements Searcher {
     private static final int FIXED = 1;
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
 
     /** 副本 */
     private SubBook _sub = null;
@@ -99,7 +99,7 @@ public class SingleWordSearcher implements Searcher {
      */
     protected SingleWordSearcher(SubBook sub, IndexStyle style, int type) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _sub = sub;
         _file = sub.getTextFile();
         _style = style;
@@ -140,8 +140,8 @@ public class SingleWordSearcher implements Searcher {
             }
         }
         try {
-            _log.debug("search word: '" + new String(_word, "x-JIS0208") + "'");
-            _log.debug("search canonical word: '" + new String(_canonical, "x-JIS0208") + "'");
+            _logger.debug("search word: '" + new String(_word, "x-JIS0208") + "'");
+            _logger.debug("search canonical word: '" + new String(_canonical, "x-JIS0208") + "'");
         } catch (UnsupportedEncodingException e) {
         }
     }
@@ -185,9 +185,9 @@ public class SingleWordSearcher implements Searcher {
                 break;
         }
         try {
-            _log.debug("compare key word: (" + comp + ") '"
-                       + new String(key, "x-JIS0208") + "' '"
-                       + new String(pattern, "x-JIS0208") + "'");
+            _logger.debug("compare key word: (" + comp + ") '"
+                          + new String(key, "x-JIS0208") + "' '"
+                          + new String(pattern, "x-JIS0208") + "'");
         } catch (UnsupportedEncodingException e) {
         }
         return comp;
@@ -259,9 +259,9 @@ public class SingleWordSearcher implements Searcher {
                 break;
         }
         try {
-            _log.debug("compare key word: (" + comp + ") '"
-                       + new String(key, "x-JIS0208") + "' '"
-                       + new String(pattern, "x-JIS0208") + "'");
+            _logger.debug("compare key word: (" + comp + ") '"
+                          + new String(key, "x-JIS0208") + "' '"
+                          + new String(pattern, "x-JIS0208") + "'");
         } catch (UnsupportedEncodingException e) {
         }
         return comp;
@@ -314,9 +314,9 @@ public class SingleWordSearcher implements Searcher {
                 break;
         }
         try {
-            _log.debug("compare key word: (" + comp + ") '"
-                       + new String(key, "x-JIS0208") + "' '"
-                       + new String(pattern, "x-JIS0208") + "'");
+            _logger.debug("compare key word: (" + comp + ") '"
+                          + new String(key, "x-JIS0208") + "' '"
+                          + new String(pattern, "x-JIS0208") + "'");
         } catch (UnsupportedEncodingException e) {
         }
         return comp;
@@ -353,8 +353,8 @@ public class SingleWordSearcher implements Searcher {
                 _entryCount = ByteUtil.getInt2(_cache, 2);
                 _off = 4;
 
-                _log.debug("page=0x" + HexUtil.toHexString(_page)
-                           + ", ID=0x" + HexUtil.toHexString(_pageID));
+                _logger.debug("page=0x" + HexUtil.toHexString(_page)
+                              + ", ID=0x" + HexUtil.toHexString(_pageID));
                 // リーフインデックスに達っしたらループ終了
                 if (_isLeafLayer(_pageID)) {
                     break;
@@ -428,8 +428,8 @@ public class SingleWordSearcher implements Searcher {
                     _entryCount = ByteUtil.getInt2(_cache, 2);
                     _entryIndex = 0;
                     _off = 4;
-                    _log.debug("page=0x" + HexUtil.toHexString(_page)
-                               + ", ID=0x" + HexUtil.toHexString(_pageID));
+                    _logger.debug("page=0x" + HexUtil.toHexString(_page)
+                                  + ", ID=0x" + HexUtil.toHexString(_pageID));
                 }
             }
 
@@ -635,18 +635,18 @@ public class SingleWordSearcher implements Searcher {
         return false;
     }
 
-//     /**
-//      * 指定されたページが階層開始ページかどうかを判別します。
-//      *
-//      * @param id ページID
-//      * @return 階層開始ページである場合はtrue、そうでない場合はfalse
-//      */
-//     private boolean _isLayerStart(int id) {
-//         if ((id & 0x40) == 0x40) {
-//             return true;
-//         }
-//         return false;
-//     }
+    // /**
+    //  * 指定されたページが階層開始ページかどうかを判別します。
+    //  *
+    //  * @param id ページID
+    //  * @return 階層開始ページである場合はtrue、そうでない場合はfalse
+    //  */
+    // private boolean _isLayerStart(int id) {
+    //     if ((id & 0x40) == 0x40) {
+    //         return true;
+    //     }
+    //     return false;
+    // }
 
     /**
      * 指定されたページが階層終了ページかどうかを判別します。
