@@ -234,6 +234,22 @@ public class ByteUtil {
         return ret;
     }
 
+    /**
+     * 指定された配列から5バイトをlong型に変換します。
+     *
+     * @param b バイト配列
+     * @param offset 変換開始位置
+     * @return 変換した数値
+     */
+    public static long getLong5(byte[] b, int offset) {
+        long ret = (long)(b[offset] & 0xff) << 32;
+        ret += ((b[offset+1] & 0xff)) << 24;
+        ret += ((b[offset+2] & 0xff) << 16);
+        ret += ((b[offset+3] & 0xff) << 8);
+        ret += (b[offset+4] & 0xff);
+        return ret;
+    }
+
     /**
      * 指定された配列から4バイトをリトルエンディアンでlong型に変換します。
      *
