@@ -5,8 +5,8 @@ import java.util.Arrays;
 import java.util.zip.CRC32;
 import java.util.zip.Deflater;
 
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * イメージ操作ユーティリティクラス。
@@ -16,7 +16,7 @@ import org.apache.commons.logging.Log;
 public class ImageUtil {
 
     /** ログ */
-    private static final Log _log = LogFactory.getLog(ImageUtil.class);
+    private static final Logger _logger = LoggerFactory.getLogger(ImageUtil.class);
 
     /** PNGヘッダ */
     private static final byte[] PNG_HEADER = {
@@ -181,7 +181,7 @@ public class ImageUtil {
      */
     public static byte[] dibToPNG(byte[] b, int level) {
         if ((b[0] & 0xff) != 'B' || (b[1] & 0xff) != 'M') {
-            _log.warn("file type 'BM' is not found in file header");
+            _logger.warn("file type 'BM' is not found in file header");
             return new byte[0];
         }
 
@@ -298,9 +298,9 @@ public class ImageUtil {
             } else if (compress == 3 && (bitCount == 16 || bitCount == 32)) {
                 // ビットフィールド
             } else {
-                _log.warn("unknown compression type:"
-                          + " compress=" + compress
-                          + " bitCount=" + bitCount);
+                _logger.warn("unknown compression type:"
+                             + " compress=" + compress
+                             + " bitCount=" + bitCount);
                 return new byte[0];
             }
         }
@@ -448,7 +448,7 @@ public class ImageUtil {
                 break;
             }
             default:
-                _log.warn("unknown bit count: " + bitCount);
+                _logger.warn("unknown bit count: " + bitCount);
                 return new byte[0];
         }
 
