@@ -442,8 +442,10 @@ public class EBZip implements EBZipConstants {
                 indexSize = 2;
             } else if (fileSize < (1<<24)) {
                 indexSize = 3;
-            } else {
+            } else if (fileSize < ((long)1<<32)) {
                 indexSize = 4;
+            } else {
+                indexSize = 5;
             }
 
             /*
@@ -490,6 +492,9 @@ public class EBZip implements EBZipConstants {
             long inTotalLength = 0;
             long outTotalLength = 0;
             int interval = 1024 >>> _level;
+            if (((totalSlice + 999) / 1000) > interval) {
+                interval = (totalSlice + 999) / 1000;
+            }
             Adler32 crc32 = new Adler32();
             Deflater def = new Deflater(Deflater.BEST_COMPRESSION);
             for (int i=0; i<totalSlice; i++) {
@@ -569,6 +574,18 @@ public class EBZip implements EBZipConstants {
                         out[6] = (byte)((nextPos >>> 8) & 0xff);
                         out[7] = (byte)(nextPos & 0xff);
                         break;
+                    case 5:
+                        out[0] = (byte)((slicePos >>> 32) & 0xff);
+                        out[1] = (byte)((slicePos >>> 24) & 0xff);
+                        out[2] = (byte)((slicePos >>> 16) & 0xff);
+                        out[3] = (byte)((slicePos >>> 8) & 0xff);
+                        out[4] = (byte)(slicePos & 0xff);
+                        out[5] = (byte)((nextPos >>> 32) & 0xff);
+                        out[6] = (byte)((nextPos >>> 24) & 0xff);
+                        out[7] = (byte)((nextPos >>> 16) & 0xff);
+                        out[8] = (byte)((nextPos >>> 8) & 0xff);
+                        out[9] = (byte)(nextPos & 0xff);
+                        break;
                     default:
                 }
 
@@ -598,11 +615,15 @@ public class EBZip implements EBZipConstants {
             out[2] = (byte)'Z';
             out[3] = (byte)'i';
             out[4] = (byte)'p';
-            out[5] = (byte)((EBFile.FORMAT_EBZIP << 4) | (_level & 0x0f));
+            if (fileSize < ((long)1<<32)) {
+                out[5] = (byte)((1 << 4) | (_level & 0x0f));
+            } else {
+                out[5] = (byte)((2 << 4) | (_level & 0x0f));
+            }
             out[6] = (byte)0;
             out[7] = (byte)0;
             out[8] = (byte)0;
-            out[9] = (byte)0;
+            out[9] = (byte)((fileSize >>> 32) & 0xff);
             out[10] = (byte)((fileSize >>> 24) & 0xff);
             out[11] = (byte)((fileSize >>> 16) & 0xff);
             out[12] = (byte)((fileSize >>> 8) & 0xff);
@@ -713,6 +734,10 @@ public class EBZip implements EBZipConstants {
             int totalSlice = (int)((bis.getFileSize()
                                     + bis.getSliceSize() - 1)
                                    / bis.getSliceSize());
+            int interval = 1024;
+            if (((totalSlice + 999) / 1000) > interval) {
+                interval = (totalSlice + 999) / 1000;
+            }
             Adler32 crc32 = new Adler32();
             for (int i=0; i<totalSlice; i++) {
                 // データの読み込み
@@ -744,7 +769,7 @@ public class EBZip implements EBZipConstants {
                 totalLength += n;
 
                 // 進捗の表示
-                if (!_quiet && (i%1024) + 1 == 1024) {
+                if (!_quiet && (i%interval) + 1 == interval) {
                     double rate = (double)(i + 1) / (double)totalSlice * 100.0;
                     System.out.println(FMT.format(rate) + " done ("
                                        + totalLength + " / "
@@ -944,10 +969,7 @@ public class EBZip implements EBZipConstants {
             bookDir = new File(_bookDir).getCanonicalPath();
             inFile = file.getCanonicalPath();
         } catch (IOException e) {
-            RuntimeException exp =
-                new RuntimeException("can't get canonical path");
-            exp.setStackTrace(e.getStackTrace());
-            throw exp;
+            throw new RuntimeException("can't get canonical path", e);
         }
 
         String fname = inFile.substring(bookDir.length());
@@ -983,13 +1005,11 @@ public class EBZip implements EBZipConstants {
         File dir = file.getParentFile();
         if (dir != null && !dir.exists()) {
             try {
-                dir.mkdirs();
+                if (!dir.mkdirs()) {
+                    throw new RuntimeException("can't create directory (" + dir.getAbsolutePath() + ")");
+                }
             } catch (SecurityException e) {
-                RuntimeException exp =
-                    new RuntimeException("can't create directory ("
-                                         + e.getMessage() + ")");
-                exp.setStackTrace(e.getStackTrace());
-                throw exp;
+                throw new RuntimeException("can't create directory (" + e.getMessage() + ")", e);
             }
         }
     }
