@@ -4,8 +4,8 @@ import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
 import org.xml.sax.ErrorHandler;
 
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * エラーハンドラ。
@@ -15,7 +15,7 @@ import org.apache.commons.logging.Log;
 class LoggingErrorHandler implements ErrorHandler {
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
 
 
     /**
@@ -24,7 +24,7 @@ class LoggingErrorHandler implements ErrorHandler {
      */
     public LoggingErrorHandler() {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
     }
 
 
@@ -36,9 +36,9 @@ class LoggingErrorHandler implements ErrorHandler {
      */
     @Override
     public void fatalError(SAXParseException exp) throws SAXException {
-        _log.fatal("[" + exp.getLineNumber()
-                   + ":" + exp.getColumnNumber() + "] "
-                   + exp.getMessage());
+        _logger.error("[" + exp.getLineNumber()
+                      + ":" + exp.getColumnNumber() + "] "
+                      + exp.getMessage());
         throw exp;
     }
 
@@ -50,9 +50,9 @@ class LoggingErrorHandler implements ErrorHandler {
      */
     @Override
     public void error(SAXParseException exp) throws SAXException {
-        _log.error("[" + exp.getLineNumber()
-                   + ":" + exp.getColumnNumber() + "] "
-                   + exp.getMessage());
+        _logger.error("[" + exp.getLineNumber()
+                      + ":" + exp.getColumnNumber() + "] "
+                      + exp.getMessage());
         throw exp;
     }
 
@@ -64,9 +64,9 @@ class LoggingErrorHandler implements ErrorHandler {
      */
     @Override
     public void warning(SAXParseException exp) throws SAXException {
-        _log.warn("[" + exp.getLineNumber()
-                  + ":" + exp.getColumnNumber() + "] "
-                  + exp.getMessage());
+        _logger.warn("[" + exp.getLineNumber()
+                     + ":" + exp.getColumnNumber() + "] "
+                     + exp.getMessage());
     }
 }
 
