@@ -9,7 +9,6 @@ import java.io.OutputStream;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.nio.channels.FileChannel;
-
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
@@ -18,9 +17,8 @@ import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
-
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.springframework.web.util.WebUtils;
 
 import fuku.eb4j.SubBook;
@@ -59,7 +57,7 @@ public class ResourceServlet extends HttpServlet {
     };
 
     /** ログ */
-    private Log _log = null;
+    private transient Logger _logger = null;
 
 
     /**
@@ -68,7 +66,7 @@ public class ResourceServlet extends HttpServlet {
      */
     public ResourceServlet() {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
     }
 
 
@@ -274,7 +272,7 @@ public class ResourceServlet extends HttpServlet {
                 width = subbook.getFont().getWideFontWidth();
             }
         } catch (EBException e) {
-            _log.warn("failed to load font image", e);
+            _logger.warn("failed to load font image", e);
             return new byte[0];
         }
         if (ArrayUtils.isEmpty(data)) {
@@ -299,7 +297,7 @@ public class ResourceServlet extends HttpServlet {
         try {
             data = subbook.getGraphicData().getMonoGraphic(pos, width, height);
         } catch (EBException e) {
-            _log.warn("failed to load mono image", e);
+            _logger.warn("failed to load mono image", e);
             return new byte[0];
         }
         if (ArrayUtils.isEmpty(data)) {
@@ -322,7 +320,7 @@ public class ResourceServlet extends HttpServlet {
         try {
             data = subbook.getGraphicData().getColorGraphic(pos);
         } catch (EBException e) {
-            _log.warn("failed to load color image", e);
+            _logger.warn("failed to load color image", e);
             return new byte[0];
         }
         if (ArrayUtils.isEmpty(data)) {
@@ -356,7 +354,7 @@ public class ResourceServlet extends HttpServlet {
                     break;
             }
         } catch (EBException e) {
-            _log.warn("failed to load sound data", e);
+            _logger.warn("failed to load sound data", e);
             return new byte[0];
         }
         if (ArrayUtils.isEmpty(data)) {
@@ -375,8 +373,10 @@ public class ResourceServlet extends HttpServlet {
         if (file == null || ArrayUtils.isEmpty(data)) {
             return;
         }
-        if (!file.getParentFile().exists()) {
-            file.getParentFile().mkdirs();
+        File dir = file.getParentFile();
+        if (!dir.exists() && !dir.mkdirs()) {
+            _logger.error("failed to create directories: " + dir.getAbsolutePath());
+            return;
         }
         FileChannel channel = null;
         FileOutputStream fos = null;
@@ -385,7 +385,7 @@ public class ResourceServlet extends HttpServlet {
             channel = fos.getChannel();
             channel.write(ByteBuffer.wrap(data));
         } catch (IOException e) {
-            _log.warn("failed to store file", e);
+            _logger.warn("failed to store file", e);
         } finally {
             IOUtils.closeQuietly(fos);
             if (channel != null) {
@@ -413,7 +413,7 @@ public class ResourceServlet extends HttpServlet {
                 out.write(b, 0, n);
             }
         } catch (IOException e) {
-            _log.warn("failed to send data", e);
+            _logger.warn("failed to send data", e);
         } finally {
             IOUtils.closeQuietly(bis);
         }
