@@ -8,9 +8,7 @@ import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
-
 import javax.servlet.ServletRequest;
-
 import javax.xml.XMLConstants;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
@@ -28,8 +26,8 @@ import org.xml.sax.SAXException;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.BooleanUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.Book;
 import fuku.eb4j.SubBook;
@@ -58,7 +56,7 @@ public class WebBookConfig {
     private static final int ANCHOR = 3;
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
 
     /** 書籍エントリリスト */
     private List<BookEntry> _bookEntryList = new ArrayList<BookEntry>();
@@ -85,7 +83,7 @@ public class WebBookConfig {
      */
     protected WebBookConfig(File workdir) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _cacheDir = new File(workdir, "webbook-cache");
     }
 
@@ -197,7 +195,7 @@ public class WebBookConfig {
                         id++;
                     }
                 } catch (EBException e) {
-                    _log.error(e.getMessage(), e);
+                    _logger.error(e.getMessage(), e);
                 }
             }
         }
