@@ -8,8 +8,8 @@ import javax.servlet.ServletContextEvent;
 import javax.servlet.ServletContextListener;
 
 import org.springframework.web.util.WebUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import static fuku.webbook.WebBookConstants.KEY_WEBBOOK_CONFIG;
 
@@ -21,7 +21,7 @@ import static fuku.webbook.WebBookConstants.KEY_WEBBOOK_CONFIG;
 public class WebBookContextListener implements ServletContextListener {
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
 
 
     /**
@@ -30,7 +30,7 @@ public class WebBookContextListener implements ServletContextListener {
      */
     public WebBookContextListener() {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
     }
 
 
@@ -57,18 +57,18 @@ public class WebBookContextListener implements ServletContextListener {
         File workdir = WebUtils.getTempDir(context);
         WebBookConfig webbookConfig = new WebBookConfig(workdir);
         if (configUrl != null && schemaUrl != null) {
-            _log.info("load configuration file [" + configUrl.toString() + "]");
+            _logger.info("load configuration file [" + configUrl.toString() + "]");
             try {
                 webbookConfig.load(configUrl, schemaUrl);
             } catch (Exception e) {
-                _log.warn("failed to initialization", e);
+                _logger.warn("failed to initialization", e);
             }
         } else {
             if (configUrl == null) {
-                _log.warn("undefined config parameter");
+                _logger.warn("undefined config parameter");
             }
             if (schemaUrl == null) {
-                _log.warn("undefined schema parameter");
+                _logger.warn("undefined schema parameter");
             }
         }
         context.setAttribute(KEY_WEBBOOK_CONFIG, webbookConfig);
