@@ -7,8 +7,8 @@ import java.util.regex.Matcher;
 import java.util.regex.PatternSyntaxException;
 
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * パターンアクセス制御クラス。
@@ -18,7 +18,7 @@ import org.apache.commons.logging.Log;
 public abstract class PatternEntry extends AbstractACLEntry {
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** パターンリスト */
     private List<Pattern> _list = new ArrayList<Pattern>();
 
@@ -31,7 +31,7 @@ public abstract class PatternEntry extends AbstractACLEntry {
      */
     protected PatternEntry(boolean allow, String list) {
         super(allow);
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         String[] str = list.split(",\\s*");
         int len = str.length;
         for (int i=0; i<len; i++) {
@@ -39,7 +39,7 @@ public abstract class PatternEntry extends AbstractACLEntry {
                 Pattern p = Pattern.compile(str[i]);
                 _list.add(p);
             } catch (PatternSyntaxException e) {
-                _log.warn(e.getMessage(), e);
+                _logger.warn(e.getMessage(), e);
             }
         }
     }
