@@ -1,7 +1,6 @@
 package fuku.webbook.taglib;
 
 import java.io.IOException;
-
 import javax.servlet.jsp.JspWriter;
 import javax.servlet.jsp.PageContext;
 import javax.servlet.jsp.JspException;
@@ -23,7 +22,7 @@ import static fuku.webbook.WebBookConstants.KEY_WEBBOOK_CONFIG;
 public class FontTableTag extends TagSupport {
 
     /** 書籍エントリ */
-    private BookEntry _entry = null;
+    private transient BookEntry _entry = null;
     /** フォントタイプ */
     private String _type = null;
 
