@@ -2,10 +2,12 @@ package fuku.webbook.acl;
 
 import org.springframework.mock.web.MockHttpServletRequest;
 
-import junit.framework.TestCase;
+import org.testng.Assert;
+import org.testng.annotations.Test;
 
-public class RoleEntryTest extends TestCase {
+public class RoleEntryTest {
 
+    @Test
     public void testAllowed() {
         MockHttpServletRequest req0 = new MockHttpServletRequest();
         req0.addUserRole("role0");
@@ -14,10 +16,11 @@ public class RoleEntryTest extends TestCase {
 
         String roleList = "role1, role2";
         RoleEntry entry = new RoleEntry(true, roleList);
-        assertFalse(entry.isAllowed(req0));
-        assertTrue(entry.isAllowed(req1));
+        Assert.assertFalse(entry.isAllowed(req0));
+        Assert.assertTrue(entry.isAllowed(req1));
     }
 
+    @Test
     public void testDenied() {
         MockHttpServletRequest req0 = new MockHttpServletRequest();
         req0.addUserRole("role0");
@@ -26,8 +29,8 @@ public class RoleEntryTest extends TestCase {
 
         String roleList = "role1, role2";
         RoleEntry entry = new RoleEntry(false, roleList);
-        assertTrue(entry.isAllowed(req0));
-        assertFalse(entry.isAllowed(req1));
+        Assert.assertTrue(entry.isAllowed(req0));
+        Assert.assertFalse(entry.isAllowed(req1));
     }
 }
 
