@@ -1,8 +1,9 @@
 #!/bin/bash
 
-BIN_DIR=`dirname $0`
-LIB_DIR=$BIN_DIR/../lib
-LOGGING_PROPERTIES=$BIN_DIR/logging.properties
+BIN_DIR=$(cd $(dirname $0) && pwd)
+BASE_DIR=$(dirname $BIN_DIR)
+LIB_DIR=$BASE_DIR/lib
+LOG4J_CONF=$BIN_DIR/log4j.xml
 
 for jar in $LIB_DIR/*.jar; do
  if [ -z "$CP" ]; then
@@ -21,6 +22,6 @@ if [ -n "$JAVA_HOME" ]; then
   fi
 fi
 
-$JAVACMD -Xmx1024m -cp $CP \
-    -Djava.util.logging.config.file=$LOGGING_PROPERTIES \
+$JAVACMD -Xmx2048m -cp $CP \
+    -Dlog4j.configuration=file://$LOG4J_CONF \
     fuku.xml2eb.Xml2Eb "$@"
