@@ -10,8 +10,8 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * インデックス出力クラス。
@@ -21,7 +21,7 @@ import org.apache.commons.logging.Log;
 public class IndexWriter {
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
 
     /** ベースファイル */
     private File _file = null;
@@ -42,7 +42,7 @@ public class IndexWriter {
      */
     public IndexWriter(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _file = file;
         _layerList = new ArrayList<IndexLayer>();
         _streamList = new ArrayList<OutputStream>();
@@ -136,7 +136,7 @@ public class IndexWriter {
      * @exception IOException 入出力エラーが発生した場合
      */
     private void _addUpperLayer(int level, Index index) throws IOException {
-        _log.trace("level=" + level + ", word=" + index.getWord());
+        _logger.trace("level=" + level + ", word=" + index.getWord());
         IndexLayer layer = _layerList.get(level);
         int wordLen = index.getWord().getWordLength();
         int curLen = layer.getWordLength();
