@@ -15,8 +15,8 @@ import java.util.Iterator;
 import java.util.Map;
 
 import org.apache.commons.io.IOUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.util.HexUtil;
 
@@ -38,7 +38,7 @@ public class Linker {
     private static final int SOUND = 8;
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
     /** 出力ファイル */
     private File _outfile = null;
     /** 入力ファイル */
@@ -59,7 +59,7 @@ public class Linker {
      */
     public Linker(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _outfile = file;
         _infile = new File[9];
         _startBlock = new long[9];
@@ -171,7 +171,7 @@ public class Linker {
                 return pos.getPosition(_startBlock[i]);
             }
         }
-        _log.warn("unknown file position: " + pos);
+        _logger.warn("unknown file position: " + pos);
         return pos.getPosition();
     }
 
@@ -230,14 +230,18 @@ public class Linker {
         for (int i=0; i<len; i++) {
             if (_infile[i] != null) {
                 if (_infile[i].exists()) {
-                    _log.info("delete file" + _infile[i].getPath());
-                    _infile[i].delete();
+                    _logger.info("delete file" + _infile[i].getPath());
+                    if (!_infile[i].delete()) {
+                        _logger.error("failed to delete file: " + _infile[i].getPath());
+                    }
                 } else {
                     File[] files = _getFileList(_infile[i]);
                     int n = files.length;
                     for (int j=0; j<n; j++) {
-                        _log.info("delete file" + files[j].getPath());
-                        files[j].delete();
+                        _logger.info("delete file" + files[j].getPath());
+                        if (!files[j].delete()) {
+                            _logger.error("failed to delete file: " + files[j].getPath());
+                        }
                     }
                 }
             }
@@ -257,7 +261,7 @@ public class Linker {
         long block = 2;
         long size;
         if (_infile[BODY] != null) {
-            _log.debug("body start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("body start block: 0x" + HexUtil.toHexString(block));
             _startBlock[BODY] = block;
             size = _setControlEntry(control, off, _infile[BODY],
                                     0x00, block, 0x02000000);
@@ -266,7 +270,7 @@ public class Linker {
             block += size;
         }
         if (_infile[MENU] != null) {
-            _log.debug("menu start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("menu start block: 0x" + HexUtil.toHexString(block));
             _startBlock[MENU] = block;
             size = _setControlEntry(control, off, _infile[MENU],
                                     0x01, block, 0x02000000);
@@ -275,7 +279,7 @@ public class Linker {
             block += size;
         }
         if (_infile[COPYRIGHT] != null) {
-            _log.debug("copyright start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("copyright start block: 0x" + HexUtil.toHexString(block));
             _startBlock[COPYRIGHT] = block;
             size = _setControlEntry(control, off, _infile[COPYRIGHT],
                                     0x02, block, 0x02000000);
@@ -284,7 +288,7 @@ public class Linker {
             block += size;
         }
         if (_infile[HEAD] != null) {
-            _log.debug("head start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("head start block: 0x" + HexUtil.toHexString(block));
             _startBlock[HEAD] = block;
             size = _setControlEntry(control, off, _infile[HEAD],
                                     0x05, block, 0x02000000);
@@ -297,7 +301,7 @@ public class Linker {
             block += size;
         }
         if (_infile[WORD] != null) {
-            _log.debug("word start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("word start block: 0x" + HexUtil.toHexString(block));
             _startBlock[WORD] = block;
             size = _setControlEntry(control, off, _getFileList(_infile[WORD]),
                                     0x91, block, 0x02415554);
@@ -306,7 +310,7 @@ public class Linker {
             block += size;
         }
         if (_infile[ENDWORD] != null) {
-            _log.debug("endword start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("endword start block: 0x" + HexUtil.toHexString(block));
             _startBlock[ENDWORD] = block;
             size = _setControlEntry(control, off, _getFileList(_infile[ENDWORD]),
                                     0x71, block, 0x02415554);
@@ -315,7 +319,7 @@ public class Linker {
             block += size;
         }
         if (_infile[KEYWORD] != null) {
-            _log.debug("keyword start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("keyword start block: 0x" + HexUtil.toHexString(block));
             _startBlock[KEYWORD] = block;
             size = _setControlEntry(control, off, _getFileList(_infile[KEYWORD]),
                                     0x80, block, 0x02415554);
@@ -324,7 +328,7 @@ public class Linker {
             block += size;
         }
         if (_infile[GRAPHIC] != null) {
-            _log.debug("graphic start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("graphic start block: 0x" + HexUtil.toHexString(block));
             _startBlock[GRAPHIC] = block;
             size = _setControlEntry(control, off, _infile[GRAPHIC],
                                     0xd2, block, 0x00000000);
@@ -333,7 +337,7 @@ public class Linker {
             block += size;
         }
         if (_infile[SOUND] != null) {
-            _log.debug("sound start block: 0x" + HexUtil.toHexString(block));
+            _logger.debug("sound start block: 0x" + HexUtil.toHexString(block));
             _startBlock[SOUND] = block;
             size = _setControlEntry(control, off, _infile[SOUND],
                                     0xd8, block, 0x00000000);
@@ -363,7 +367,7 @@ public class Linker {
         _fileMap.clear();
 
         // ファイルの結合
-        _log.info("link file: " + _outfile.getPath());
+        _logger.info("link file: " + _outfile.getPath());
         BlockOutputStream out = null;
         try {
             out =
@@ -379,7 +383,7 @@ public class Linker {
                 }
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(out);
         }
@@ -444,7 +448,7 @@ public class Linker {
      */
     private void _fixBodyReference() {
         Map<Position,String> map = _ref.getBodyRef();
-        _log.info("resolve body reference: " + map.size());
+        _logger.info("resolve body reference: " + map.size());
         Iterator<Map.Entry<Position,String>> it = map.entrySet().iterator();
         while (it.hasNext()) {
             Map.Entry<Position,String> entry = it.next();
@@ -454,7 +458,7 @@ public class Linker {
                 Position tpos = _ref.getBodyTag(tag);
                 _fixPosition(pos, _getPosition(tpos));
             } else {
-                _log.error("undefined body tag: " + tag);
+                _logger.error("undefined body tag: " + tag);
             }
         }
     }
@@ -465,7 +469,7 @@ public class Linker {
      */
     private void _fixHeadReference() {
         Map<Position,String> map = _ref.getHeadRef();
-        _log.info("resolve head reference: " + map.size());
+        _logger.info("resolve head reference: " + map.size());
         Iterator<Map.Entry<Position,String>> it = map.entrySet().iterator();
         while (it.hasNext()) {
             Map.Entry<Position,String> entry = it.next();
@@ -475,7 +479,7 @@ public class Linker {
                 Position tpos = _ref.getHeadTag(tag);
                 _fixPosition(pos, _getPosition(tpos));
             } else {
-                _log.error("undefined head tag: " + tag);
+                _logger.error("undefined head tag: " + tag);
             }
         }
     }
@@ -486,7 +490,7 @@ public class Linker {
      */
     private void _fixIndexReference() {
         Map<Position,String> map = _ref.getIndexRef();
-        _log.info("resolve index reference: " + map.size());
+        _logger.info("resolve index reference: " + map.size());
         Iterator<Map.Entry<Position,String>> it = map.entrySet().iterator();
         while (it.hasNext()) {
             Map.Entry<Position,String> entry = it.next();
@@ -502,7 +506,7 @@ public class Linker {
      */
     private void _fixGraphicReference() {
         Map<Position,String> map = _ref.getGraphicRef();
-        _log.info("resolve graphic reference: " + map.size());
+        _logger.info("resolve graphic reference: " + map.size());
         Iterator<Map.Entry<Position,String>> it = map.entrySet().iterator();
         while (it.hasNext()) {
             Map.Entry<Position,String> entry = it.next();
@@ -512,7 +516,7 @@ public class Linker {
                 Position tpos = _ref.getGraphicTag(tag);
                 _fixPosition(pos, _getPosition(tpos));
             } else {
-                _log.error("undefined graphic tag: " + tag);
+                _logger.error("undefined graphic tag: " + tag);
             }
         }
     }
@@ -523,7 +527,7 @@ public class Linker {
      */
     private void _fixSoundReference() {
         Map<Position,String> map = _ref.getSoundRef();
-        _log.info("resolve sound reference:" + map.size());
+        _logger.info("resolve sound reference:" + map.size());
         Iterator<Map.Entry<Position,String>> it = map.entrySet().iterator();
         while (it.hasNext()) {
             Map.Entry<Position,String> entry = it.next();
@@ -533,7 +537,7 @@ public class Linker {
                 Position[] tpos = _ref.getSoundTag(tag);
                 _fixPosition(pos, _getPosition(tpos[0]), _getPosition(tpos[1]));
             } else {
-                _log.error("undefined sound tag: " + tag);
+                _logger.error("undefined sound tag: " + tag);
             }
         }
     }
@@ -568,7 +572,7 @@ public class Linker {
             stream.seek(pos.getPosition());
             stream.write(b, 0, b.length);
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         }
     }
 
@@ -611,7 +615,7 @@ public class Linker {
             stream.seek(pos.getPosition());
             stream.write(b, 0, b.length);
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         }
     }
 
@@ -637,14 +641,14 @@ public class Linker {
             base = name.substring(0, idx);
             block = Integer.parseInt(tag);
         } catch (NumberFormatException e) {
-            _log.warn(e.getMessage(), e);
+            _logger.warn(e.getMessage(), e);
         }
         if (level <= 0) {
-            _log.error("unknown index file: " + name);
+            _logger.error("unknown index file: " + name);
             return;
         }
         if (block <= 0) {
-            _log.error("unknown index tag: " + tag);
+            _logger.error("unknown index tag: " + tag);
             return;
         }
         long size = 0;
@@ -661,7 +665,7 @@ public class Linker {
                 }
                 size += indexFile[i].length();
             } catch (NumberFormatException e) {
-                _log.warn(e.getMessage(), e);
+                _logger.warn(e.getMessage(), e);
             }
         }
         block += (size / 2048);
@@ -675,11 +679,11 @@ public class Linker {
                    && base.equals(_infile[KEYWORD].getName())) {
             block += _startBlock[KEYWORD];
         } else {
-            _log.error("unknown index file: " + name);
+            _logger.error("unknown index file: " + name);
             return;
         }
         block--;
-        _log.debug(pos + ": 0x" + HexUtil.toHexString(block) + " tag=" + tag);
+        _logger.debug(pos + ": 0x" + HexUtil.toHexString(block) + " tag=" + tag);
         byte[] b = new byte[4];
         b[0] = (byte)((block >>> 24) & 0xff);
         b[1] = (byte)((block >>> 16) & 0xff);
@@ -694,7 +698,7 @@ public class Linker {
             stream.seek(pos.getPosition());
             stream.write(b, 0, b.length);
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         }
     }
 
@@ -714,7 +718,7 @@ public class Linker {
             }
             return;
         }
-        _log.info("link file: " + file.getPath());
+        _logger.info("link file: " + file.getPath());
         byte[] b = new byte[2048];
         int n;
         BufferedInputStream bis = null;
@@ -728,7 +732,7 @@ public class Linker {
                 out.write(b, 0, n);
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(bis);
         }
