@@ -9,8 +9,8 @@ import javax.sound.sampled.AudioFormat;
 
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.hook.Hook;
 import fuku.eb4j.util.ByteUtil;
@@ -41,7 +41,7 @@ public class TextOutputStream extends BlockOutputStream {
     private static final Integer SOUND = Integer.valueOf(10);
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
 
     /** 制御記述子スタック */
     private Stack<Integer> _stack = new Stack<Integer>();;
@@ -61,7 +61,7 @@ public class TextOutputStream extends BlockOutputStream {
      */
     public TextOutputStream(File file, OutputStream out) {
         super(out);
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _file = file;
     }
 
@@ -714,13 +714,13 @@ public class TextOutputStream extends BlockOutputStream {
             if (channels == 2) {
                 flags |= 0x1000;
             } else if (channels != 1) {
-                _log.warn("unsupported channnels: " + channels + " [" + name + "]");
+                _logger.warn("unsupported channnels: " + channels + " [" + name + "]");
             }
             int bits = audioFormat.getSampleSizeInBits();
             if (bits == 8) {
                 flags |= 0x0010;
             } else if (bits != 16) {
-                _log.warn("unsupported bits per sample: " + bits + " [" + name + "]");
+                _logger.warn("unsupported bits per sample: " + bits + " [" + name + "]");
             }
             float sampleRate = audioFormat.getSampleRate();
             if (sampleRate == 22050.0f) {
@@ -728,7 +728,7 @@ public class TextOutputStream extends BlockOutputStream {
             } else if (sampleRate == 11025.0f) {
                 flags |= 0x0002;
             } else if (sampleRate != 44100.0f) {
-                _log.warn("unsupported sample rate: " + sampleRate + " [" + name + "]");
+                _logger.warn("unsupported sample rate: " + sampleRate + " [" + name + "]");
             }
         } else {
             flags = 0x0012;
