@@ -6,8 +6,8 @@ import java.util.TreeSet;
 
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.util.ByteUtil;
 import fuku.xml2eb.util.UnicodeUtil;
@@ -23,7 +23,7 @@ public class WordSet extends TreeSet<Word> {
     public static final int DIRECTION_ENDWORD = 1;
 
     /** ログ */
-    private Log _log = null;
+    private transient Logger _logger = null;
     /** 単語の解析方向 */
     private int _direction = 0;
 
@@ -35,7 +35,7 @@ public class WordSet extends TreeSet<Word> {
      */
     public WordSet(int direction) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _direction = direction;
     }
 
@@ -126,7 +126,7 @@ public class WordSet extends TreeSet<Word> {
             }
         }
         if (idx == 0) {
-            _log.warn("word is empty: '" + word + "' [id=" + tag + "]");
+            _logger.warn("word is empty: '" + word + "' [id=" + tag + "]");
             return;
         }
         if (idx > 255) {
@@ -139,8 +139,7 @@ public class WordSet extends TreeSet<Word> {
             ByteUtil.reverseWord(buf);
         }
         try {
-            _log.trace("add word: "
-                       + new String(buf, "x-JIS0208") + " [" + word + "]");
+            _logger.trace("add word: " + new String(buf, "x-JIS0208") + " [" + word + "]");
         } catch (UnsupportedEncodingException e) {
         }
         Word wd = new Word(buf, tag);
@@ -159,8 +158,7 @@ public class WordSet extends TreeSet<Word> {
         }
         if (katakana) {
             try {
-                _log.trace("add word: "
-                           + new String(buf, "x-JIS0208") + " [" + word + "]");
+                _logger.trace("add word: " + new String(buf, "x-JIS0208") + " [" + word + "]");
             } catch (UnsupportedEncodingException e) {
             }
             wd = new Word(buf, tag);
