@@ -28,8 +28,8 @@ import org.xml.sax.SAXException;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.LogFactory;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import fuku.eb4j.util.ByteUtil;
 
@@ -73,7 +73,7 @@ public class Xml2Eb {
     private static final int MAX_FONT = 94 * 94;
 
     /** ログ */
-    private Log _log = null;
+    private Logger _logger = null;
 
     /** ベースディレクトリ */
     private File _basedir = null;
@@ -115,7 +115,7 @@ public class Xml2Eb {
      */
     public Xml2Eb(File file) {
         super();
-        _log = LogFactory.getLog(getClass());
+        _logger = LoggerFactory.getLogger(getClass());
         _xmlfile = file;
         _basedir = file.getParentFile();
         if (_basedir == null) {
@@ -149,16 +149,16 @@ public class Xml2Eb {
         factory.setIgnoringElementContentWhitespace(true);
         DocumentBuilder builder = factory.newDocumentBuilder();
         builder.setErrorHandler(new LoggingErrorHandler());
-        _log.info("load file: " + _xmlfile.getPath());
+        _logger.info("load file: " + _xmlfile.getPath());
         _doc = builder.parse(_xmlfile);
 
         Node root = _doc.getFirstChild();
         if (root.getNodeType() != Node.ELEMENT_NODE) {
-            _log.fatal("root element node not found");
+            _logger.error("root element node not found");
             return;
         }
         if (!"book".equals(root.getNodeName())) {
-            _log.fatal("book element node not found");
+            _logger.error("book element node not found");
             return;
         }
         Element book = (Element)root;
@@ -188,8 +188,12 @@ public class Xml2Eb {
         File dicdir = new File(_outdir, dir);
         File datadir = new File(dicdir, DATA_DIR);
         File fontdir = new File(dicdir, EXT_FONT_DIR);
-        datadir.mkdirs();
-        fontdir.mkdirs();
+        if (!datadir.exists() && !datadir.mkdirs()) {
+            _logger.error("failed to create directories: " + datadir.getPath());
+        }
+        if (!fontdir.exists() && !fontdir.mkdirs()) {
+            _logger.error("failed to create directories: " + fontdir.getPath());
+        }
 
         Reference ref = new Reference();
 
@@ -197,7 +201,7 @@ public class Xml2Eb {
         try {
             info.setType(Integer.decode(type));
         } catch (NumberFormatException e) {
-            _log.warn("unknown subbook type: " + type);
+            _logger.warn("unknown subbook type: " + type);
         }
         info.setTitle(title);
         info.setDirectory(dir);
@@ -218,7 +222,7 @@ public class Xml2Eb {
                 String wtype = charElem.getAttribute("type");
                 Map<Integer,List<String>> map = null;
                 if (ref.hasNarrowChar(name) || ref.hasWideChar(name)) {
-                    _log.warn("character name has already been defined: " + name);
+                    _logger.warn("character name has already been defined: " + name);
                     continue;
                 }
                 if ("narrow".equals(wtype)) {
@@ -236,7 +240,7 @@ public class Xml2Eb {
                     }
                     map = fmap;
                 } else {
-                    _log.warn("unknown font type: " + wtype);
+                    _logger.warn("unknown font type: " + wtype);
                     continue;
                 }
                 NodeList dataList = charElem.getElementsByTagName("data");
@@ -251,7 +255,7 @@ public class Xml2Eb {
                     } catch (NumberFormatException e) {
                     }
                     if (key != 16 && key != 24 && key != 30 && key != 48) {
-                        _log.warn("unknown font size: " + size);
+                        _logger.warn("unknown font size: " + size);
                         continue;
                     }
                     List<String> list = map.get(Integer.valueOf(key));
@@ -289,6 +293,8 @@ public class Xml2Eb {
                         width = 24;
                         info.setExtFont(CatalogInfo.FONT_48_NARROW, name);
                         break;
+                    default:
+                        break;
                 }
                 File file = new File(fontdir, name);
                 List<String> list = entry.getValue();
@@ -322,6 +328,8 @@ public class Xml2Eb {
                         width = 48;
                         info.setExtFont(CatalogInfo.FONT_48_WIDE, name);
                         break;
+                    default:
+                        break;
                 }
                 File file = new File(fontdir, name);
                 List<String> list = entry.getValue();
@@ -430,19 +438,19 @@ public class Xml2Eb {
      * @param ref 参照情報
      */
     private void _writeCopyright(File file, Node node, Reference ref) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         TextOutputStream stream = null;
         try {
             stream =
                 new TextOutputStream(file,
-                    new BufferedOutputStream(
-                        new FileOutputStream(file)));
+                                     new BufferedOutputStream(
+                                         new FileOutputStream(file)));
             stream.setReference(ref);
             stream.beginContext();
             _writeNode(stream, node, 1, ref);
             stream.endContext();
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(stream);
         }
@@ -457,28 +465,28 @@ public class Xml2Eb {
      */
     private void _writeMenu(File file, Element menu, Reference ref) {
         NodeList layerList = menu.getElementsByTagName("layer");
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         TextOutputStream stream = null;
         try {
             stream =
                 new TextOutputStream(file,
-                    new BufferedOutputStream(
-                        new FileOutputStream(file)));
+                                     new BufferedOutputStream(
+                                         new FileOutputStream(file)));
             stream.setReference(ref);
             int len = layerList.getLength();
-            _log.info("layer count: " + len);
+            _logger.info("layer count: " + len);
             for (int i=0; i<len; i++) {
                 Element layerElem = (Element)layerList.item(i);
                 String id = layerElem.getAttribute("id");
                 ref.putBodyTag(id, file, stream.getSize());
-                _log.trace("layer: '" + id + "'");
+                _logger.trace("layer: '" + id + "'");
                 stream.beginContext();
                 stream.setIndent(1);
                 _writeNode(stream, layerElem, 2, ref);
                 stream.endContext();
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(stream);
         }
@@ -492,22 +500,22 @@ public class Xml2Eb {
      * @param ref 参照情報
      */
     private void _writeHead(File file, NodeList itemList, Reference ref) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         TextOutputStream stream = null;
         try {
             stream =
                 new TextOutputStream(file,
-                    new BufferedOutputStream(
-                        new FileOutputStream(file)));
+                                     new BufferedOutputStream(
+                                         new FileOutputStream(file)));
             stream.setReference(ref);
             stream.beginContext();
             int len = itemList.getLength();
-            _log.info("item count: " + len);
+            _logger.info("item count: " + len);
             for (int i=0; i<len; i++) {
                 Element itemElem = (Element)itemList.item(i);
                 String id = itemElem.getAttribute("id");
                 ref.putHeadTag(id, file, stream.getSize());
-                _log.trace("head: '" + id + "'");
+                _logger.trace("head: '" + id + "'");
                 NodeList headList = itemElem.getElementsByTagName("head");
                 int n = headList.getLength();
                 for (int j=0; j<n; j++) {
@@ -518,7 +526,7 @@ public class Xml2Eb {
             }
             stream.endContext();
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(stream);
         }
@@ -532,22 +540,22 @@ public class Xml2Eb {
      * @param ref 参照情報
      */
     private void _writeBody(File file, NodeList itemList, Reference ref) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         TextOutputStream stream = null;
         try {
             stream =
                 new TextOutputStream(file,
-                    new BufferedOutputStream(
-                        new FileOutputStream(file)));
+                                     new BufferedOutputStream(
+                                         new FileOutputStream(file)));
             stream.setReference(ref);
             stream.beginContext();
             int len = itemList.getLength();
-            _log.info("item count: " + len);
+            _logger.info("item count: " + len);
             for (int i=0; i<len; i++) {
                 Element itemElem = (Element)itemList.item(i);
                 String id = itemElem.getAttribute("id");
                 ref.putBodyTag(id, file, stream.getSize());
-                _log.trace("body: '" + id + "'");
+                _logger.trace("body: '" + id + "'");
                 NodeList bodyList = itemElem.getElementsByTagName("body");
                 int n = bodyList.getLength();
                 for (int j=0; j<n; j++) {
@@ -558,7 +566,7 @@ public class Xml2Eb {
             }
             stream.endContext();
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(stream);
         }
@@ -574,7 +582,7 @@ public class Xml2Eb {
      * @return 検索語が存在した場合はtrue、そうでない場合はfalse
      */
     private boolean _writeWordIndex(File file, NodeList itemList, int direction, Reference ref) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         IndexWriter iw = null;
         boolean avail = false;
         try {
@@ -588,11 +596,11 @@ public class Xml2Eb {
                 for (int j=0; j<n; j++) {
                     Element wordElem = (Element)wordList.item(j);
                     String str = wordElem.getTextContent();
-                    _log.trace("word: '" + str + "'");
+                    _logger.trace("word: '" + str + "'");
                     wordSet.add(str, id);
                 }
             }
-            _log.info("word count: " + wordSet.size());
+            _logger.info("word count: " + wordSet.size());
             avail = !wordSet.isEmpty();
             if (avail) {
                 iw = new IndexWriter(file);
@@ -600,7 +608,7 @@ public class Xml2Eb {
                 iw.write(wordSet);
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             if (iw != null) {
                 iw.close();
@@ -619,7 +627,7 @@ public class Xml2Eb {
      * @return キーワードが存在した場合はtrue、そうでない場合はfalse
      */
     private boolean _writeKeywordIndex(File file, NodeList itemList, int direction, Reference ref) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         IndexWriter iw = null;
         boolean avail = false;
         try {
@@ -633,11 +641,11 @@ public class Xml2Eb {
                 for (int j=0; j<n; j++) {
                     Element wordElem = (Element)wordList.item(j);
                     String str = wordElem.getTextContent();
-                    _log.trace("keyword: '" + str + "'");
+                    _logger.trace("keyword: '" + str + "'");
                     wordSet.add(str, id);
                 }
             }
-            _log.info("word count: " + wordSet.size());
+            _logger.info("word count: " + wordSet.size());
             avail = !wordSet.isEmpty();
             if (avail) {
                 iw = new IndexWriter(file);
@@ -645,7 +653,7 @@ public class Xml2Eb {
                 iw.write(wordSet);
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             if (iw != null) {
                 iw.close();
@@ -681,9 +689,7 @@ public class Xml2Eb {
                         stream.append(str);
                     }
                 } else {
-                    IOException exp = new IOException();
-                    exp.initCause(e);
-                    throw exp;
+                    throw new IOException(e);
                 }
             }
         } else if (ntype == Node.ELEMENT_NODE) {
@@ -807,7 +813,7 @@ public class Xml2Eb {
      * @param ref 参照情報
      */
     private void _writeGraphic(File file, String[] src, String[] key, String[] format, Reference ref) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         BlockOutputStream stream = null;
         long pos = 0L;
         try {
@@ -821,7 +827,7 @@ public class Xml2Eb {
             header[2] = 't';
             header[3] = 'a';
             int len = src.length;
-            _log.info("graphic file count: " + len);
+            _logger.info("graphic file count: " + len);
             for (int i=0; i<len; i++) {
                 File imgfile = new File(_basedir, src[i]);
                 byte[] buf = null;
@@ -829,7 +835,7 @@ public class Xml2Eb {
                     buf = FileUtils.readFileToByteArray(imgfile);
                 } catch (IOException e) {
                     buf = new byte[0];
-                    _log.warn("failed to load graphic file: " + imgfile.getPath());
+                    _logger.warn("failed to load graphic file: " + imgfile.getPath());
                 }
                 int size = buf.length;
                 header[4] = (byte)(size & 0xff);
@@ -843,7 +849,7 @@ public class Xml2Eb {
                 pos = stream.getSize();
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(stream);
         }
@@ -859,7 +865,7 @@ public class Xml2Eb {
      * @param ref 参照情報
      */
     private void _writeSound(File file, String[] src, String[] key, String[] format, Reference ref) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         BlockOutputStream stream = null;
         long pos1 = 0L;
         long pos2 = 0L;
@@ -869,7 +875,7 @@ public class Xml2Eb {
                     new BufferedOutputStream(
                         new FileOutputStream(file)));
             int len = src.length;
-            _log.info("sound file count: " + len);
+            _logger.info("sound file count: " + len);
             for (int i=0; i<len; i++) {
                 File sndfile = new File(_basedir, src[i]);
                 byte[] buf = null;
@@ -877,7 +883,7 @@ public class Xml2Eb {
                     buf = FileUtils.readFileToByteArray(sndfile);
                 } catch (IOException e) {
                     buf = new byte[0];
-                    _log.warn("failed to load sound file: " + sndfile.getPath());
+                    _logger.warn("failed to load sound file: " + sndfile.getPath());
                 }
                 int size = buf.length;
                 int off = 0;
@@ -902,7 +908,7 @@ public class Xml2Eb {
                 pos1 = pos2;
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(stream);
         }
@@ -917,7 +923,7 @@ public class Xml2Eb {
      * @param height 縦ドット数
      */
     private void _writeExtFont(File file, String[] src, int width, int height) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         BlockOutputStream stream = null;
         try {
             stream =
@@ -926,12 +932,12 @@ public class Xml2Eb {
                         new FileOutputStream(file)));
             int len = src.length;
             if (len > MAX_FONT) {
-                _log.warn("too many fonts defined: "
-                          + width + "x" + height + " = " + len
-                          + " (max=" + MAX_FONT + ")");
+                _logger.warn("too many fonts defined: "
+                             + width + "x" + height + " = " + len
+                             + " (max=" + MAX_FONT + ")");
                 len = MAX_FONT;
             }
-            _log.info(width + "x" + height + " xbm file count: " + len);
+            _logger.info(width + "x" + height + " xbm file count: " + len);
             byte[] buf = new byte[2048];
             Arrays.fill(buf, (byte)0x00);
             buf[8] = (byte)width;
@@ -961,7 +967,7 @@ public class Xml2Eb {
                         int n = Math.min(b.length, size);
                         System.arraycopy(b, 0, buf, off, n);
                     } catch (IOException e) {
-                        _log.warn("failed to load XBM file: " + xbmfile.getPath(), e);
+                        _logger.warn("failed to load XBM file: " + xbmfile.getPath(), e);
                     }
                     off += size;
                 }
@@ -969,7 +975,7 @@ public class Xml2Eb {
                 stream.flush();
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(stream);
         }
@@ -982,7 +988,7 @@ public class Xml2Eb {
      * @param info 書籍管理情報
      */
     private void _writeCatalogs(File file, CatalogInfo[] info) {
-        _log.info("write file: " + file.getPath());
+        _logger.info("write file: " + file.getPath());
         BlockOutputStream stream = null;
         try {
             stream =
@@ -991,7 +997,7 @@ public class Xml2Eb {
                         new FileOutputStream(file)));
             int len = info.length;
             if (len > 12) {
-                _log.warn("maximum subbook count is 12: " + len);
+                _logger.warn("maximum subbook count is 12: " + len);
                 len = 12;
             }
             byte[] buf = new byte[16];
@@ -1016,7 +1022,7 @@ public class Xml2Eb {
                 byte[] b = ByteUtil.stringToJISX0208(info[i].getTitle());
                 int n = b.length;
                 if (n > 80) {
-                    _log.warn("[subbook #" + (i+1) + "] title is too long");
+                    _logger.warn("[subbook #" + (i+1) + "] title is too long");
                     n = 80;
                 }
                 System.arraycopy(b, 0, buf, idx, n);
@@ -1026,7 +1032,7 @@ public class Xml2Eb {
                 b = info[i].getDirectory().getBytes("ISO-8859-1");
                 n = b.length;
                 if (n > 8) {
-                    _log.warn("[subbook #" + (i+1) + "] directory name is too long");
+                    _logger.warn("[subbook #" + (i+1) + "] directory name is too long");
                     n = 8;
                 }
                 System.arraycopy(b, 0, buf, idx, n);
@@ -1046,7 +1052,7 @@ public class Xml2Eb {
                         b = font[j].getBytes("ISO-8859-1");
                         n = b.length;
                         if (n > 8) {
-                            _log.warn("[subbook #" + (i+1) + "] font name is too long");
+                            _logger.warn("[subbook #" + (i+1) + "] font name is too long");
                             n = 8;
                         }
                         System.arraycopy(b, 0, buf, idx, n);
@@ -1057,7 +1063,7 @@ public class Xml2Eb {
                 stream.flush();
             }
         } catch (IOException e) {
-            _log.error(e.getMessage(), e);
+            _logger.error(e.getMessage(), e);
         } finally {
             IOUtils.closeQuietly(stream);
         }
